// AocsDataPool.h
//
// Version	1.0
// Date		14.03.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Base class for all AOCS data pool classes
//
// -------------------------------------------------------------------

#ifndef AocsDataPoolH
#define AocsDataPoolH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../BasicObjects/AocsObject.h"
#include "../FailureDetection/ConsistencyCheckable.h"
#include "../ObjectList/ObjectListTemplate.h"
#include "../AocsData/AocsData.h"

// -------------------------------------------------------------------

class AocsDataPool : public AocsObject, public ConsistencyCheckable {

	void localReset();
	void localResetConfiguration();

	// 'list' holds the references to the AOCS data objects in the pool.
	ObjectListTemplate<AocsData> aocsDataList;

	// Recovery action associated to the consistency check test
	RecoveryAction* recoveryAction;

protected :

	// Only concrete AOCS data pools can be instantiated
	AocsDataPool();

	// Load the references of concrete data in a pool in the pool object list
	void loadData(AocsData* data)
		{ aocsDataList.addObject(data); }

	// Configure the object list by assigning memory for it
	void configureAocsDataList(int size)
		{ aocsDataList.allocateMemory(size); }

public :

	// Methods to iterate through the items in the data pool
	AocsData* first()
		{ return aocsDataList.first(); }
	AocsData* next()
		{ return aocsDataList.next(); }
	bool isLast()
		{ return aocsDataList.isLast(); }

	// Methods inherited from base classes

	virtual void reset();				// pure virtual method from Resettable
										
	virtual void resetConfiguration();	// pure virtual methods from Configurable
	virtual bool isConfigured();
	
										// pure virtual methods from Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual void setTelemetryFormat(TelemetryFormat newFormat);
	virtual int getTelemetryImageLength();
										
	virtual bool doConsistencyCheck();	// pure virtual methods from ConsistencyCheckable
	virtual RecoveryAction* getRecoveryAction()
		{ return recoveryAction; }
	virtual void setRecoveryAction(RecoveryAction* r)
		{ recoveryAction = r; }

};

// -------------------------------------------------------------------
#endif
