// TestCaseAocsData_3.cpp
//
// Version	1.0
// Date		10.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include <math.h>

#include "TestCaseAocsData_3.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/AocsData.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/DataItemWrite.h"
#include "../../AocsData/DataItemRead.h"
#include "../../OperatingSystemObjects/DummyAocsClock.h"

// -------------------------------------------------------------------
TestCaseAocsData_3::TestCaseAocsData_3():
	TestCaseGenericSetUp(ID_AOCSDATA*10+3,"TestCaseAocsData_3") {
		return;
}

// -------------------------------------------------------------------

void TestCaseAocsData_3::runTestCase() {

	Scalar d1, d2;

	// Set closeness thresholds
	Real epsilon=(Real)0.2;
	d1.setClosenessThreshold(epsilon);
	d2.setClosenessThreshold((Real)(0.000001*epsilon));
	
	// Reset the two scalars
	d1.reset();
	d2.reset();

	// Get the write access to the scalar data item
	DataItemWrite w1 = d1.getDataItemWrite(0);
	DataItemWrite w2 = d2.getDataItemWrite(0);

	// Set the data item equal to 2 and 2+epsilon/2 
	w1.set(2);
	w2.set(2+epsilon/2);

	// Check the distance between the scalars (allow for possible rounding errors!)
	if ( fabs(d1.distance(&d2) - epsilon/2)>0.0000001 )
	{	setTestResult(TEST_FAILURE, "Incorrect distance");
		return;
	}

	if ( fabs(d2.distance(&d1)-epsilon/2)>0.0000001 )
	{	setTestResult(TEST_FAILURE, "Incorrect distance");
		return;
	}

	// Check that the scalars are "close"
	if (!d1.close(&d2))
	{	setTestResult(TEST_FAILURE, "Scalars should be close");
		return;
	}

	if (!d2.close( &d1, (Real)(0.75*epsilon) ))
	{	setTestResult(TEST_FAILURE, "Scalars should be close");
		return;
	}

	if (d2.close(&d1))
	{	setTestResult(TEST_FAILURE, "Scalars should be close");
		return;
	}

	// Check the correct size of the scalars
	if ( fabs(d1.size()-2) > 0.0000001)
	{	setTestResult(TEST_FAILURE, "Incorrect scalar size");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
