// TestCaseAocsData_6.cpp
//
// Version	1.0
// Date		13.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include <math.h>

#include "TestCaseAocsData_6.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/AocsData.h"
#include "../../AocsData/TwoEulerAngles.h"
#include "../../AocsData/DataItemWrite.h"
#include "../../AocsData/DataItemRead.h"
#include "../../OperatingSystemObjects/DummyAocsClock.h"

// -------------------------------------------------------------------
TestCaseAocsData_6::TestCaseAocsData_6():
	TestCaseGenericSetUp(ID_AOCSDATA*10+6,"TestCaseAocsData_6") {
		return;
}

// -------------------------------------------------------------------

void TestCaseAocsData_6::runTestCase() {

	TwoEulerAngles e1;

	// Reset the AOCS datum
	e1.reset();

	// Get the write access to the AOCS data item
	DataItemWrite w10 = e1.getDataItemWrite(0);
	DataItemWrite w11 = e1.getDataItemWrite(1);

	// Set the first component of TwoEulerAngles object 
	w10.set(1);

	// Set the second component of the TwoEulerAngles object 
	w11.set(2);

	// Get and check the property associated to the first data item
	Property p10=e1.getProperty(0);
	if (p10.get() != 1)
	{	setTestResult(TEST_FAILURE, "Incorrect property");
		return;
	}

	if ((int)p10.getPropertyId() != (int)0*MAX_INSTANCE_ID+e1.getInstanceId())
	{	setTestResult(TEST_FAILURE, "Incorrect property");
		return;
	}

	// Get and check the property associated to the first data item
	Property p11=e1.getProperty(1);
	if (p11.get() != 2)
	{	setTestResult(TEST_FAILURE, "Incorrect property");
		return;
	}

	if ((int)p11.getPropertyId() != (int)1*MAX_INSTANCE_ID+e1.getInstanceId())
	{	setTestResult(TEST_FAILURE, "Incorrect property");
		return;
	}

	// Check that no failure or configuration events have been created
	if ( failureEvtRep.getCounter() != failureEvtN )
	{	setTestResult(TEST_FAILURE, "Failure event was generated");
		return;
	}
	if ( configEvtRep.getCounter() != configEvtN )
	{	setTestResult(TEST_FAILURE, "Configuration event was generated");
		return;
	}

	// Attempt to retrieve a non-existent property
	p11=e1.getProperty(2);

	// Check that the null property was returned
	if (p11.getPropertyId() != 0)
	{	setTestResult(TEST_FAILURE, "Incorrect property");
		return;
	}

	// Check that one configuration error event was created
	if ( configEvtRep.getCounter() != configEvtN+1 )
	{	setTestResult(TEST_FAILURE, "Configuration event was not generated");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
