// AttitudeDataPool.cpp
//
// Version	1.0
// Date		15.03.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../AocsData/AttitudeDataPool.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsData/TwoEulerAngles.h"
#include "../AocsData/ThreeEulerAngles.h"
#include "../AocsData/Scalar.h"
#include "../AocsData/NVector.h"

// -------------------------------------------------------------------
// The constructor should load the references to the data in the pool in the
// object list array. In order to do this, it should first configure the list
// by calling its allocateMemory method.
// The constructor resets the data in the pool by calling methods reset and
// reset configuration on the base AocsDataPool class.

AttitudeDataPool::AttitudeDataPool()
{
	setClassId(ID_ATTITUDEDATAPOOL);	

	configureAocsDataList(14);			// there are 14 data in the pool

	// Create data pool variables
	fssData = new TwoEulerAngles;
	sas1Data = new TwoEulerAngles;
	sas2Data = new TwoEulerAngles;
	sas3Data = new TwoEulerAngles;
	gyrRate = new Scalar;

	scTorque = new NVector(3);
	rwAngularMomentum = new NVector(3);
	rwTorque = new NVector(4);
	rwSpeed = new NVector(4);
	thuOnTime = new NVector(6);
	thuDelayTime = new NVector(6);

	attEstimate = new ThreeEulerAngles;
	attSetPoint = new ThreeEulerAngles;
	attError = new ThreeEulerAngles;

	// Load data pool variables in the internal list
	loadData(fssData);
	loadData(gyrRate);
	loadData(sas1Data);
	loadData(sas2Data);
	loadData(sas3Data);
	loadData(rwSpeed);

	loadData(scTorque);
	loadData(rwAngularMomentum);
	loadData(rwTorque);
	loadData(thuOnTime);
	loadData(thuDelayTime);

	loadData(attEstimate);
	loadData(attSetPoint);
	loadData(attError);

	// Reset the data pool and its configuration
	AocsDataPool::reset();
	AocsDataPool::resetConfiguration();
}
