// AocsEvent.cpp
//
// Version	1.0
// Date		07.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/AocsEvent.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../BasicObjects/AocsObject.h"
#include "../SystemManagement/SystemManager.h"
#include "../TelemetryManagement/TelemetryStream.h"

// -------------------------------------------------------------------
// Define static variables
int AocsEvent::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------
// AOCS Events must de-register from the SystemManager because their
// system management is already done by their event repositories.

AocsEvent::AocsEvent()
{
	setClassId(ID_AOCSEVENT);			

	tmImageLength[shortTm]  = 8*sizeof(EventType);	
	tmImageLength[normalTm] = 8*sizeof(EventType);
	tmImageLength[longTm]   = 8*(sizeof(EventType)+sizeof(InstanceId)+sizeof(AocsTime));
	tmImageLength[debugTm]  = 8*(sizeof(EventType)+sizeof(InstanceId)+sizeof(AocsTime));

	if (AocsObject::getSystemManager()!=NULL)	
		AocsObject::getSystemManager()->remove(this);		

	localResetConfiguration();				

}

// -------------------------------------------------------------------

void AocsEvent::initialize(AocsObject* c, EventType t) 
{
	timeStamp = getTime();
	creator = c;
	evtType = t;
}

// -------------------------------------------------------------------

void AocsEvent::localResetConfiguration()
{
	creator = NULL;
	timeStamp = 0;
	evtType = 0;
}


// -------------------------------------------------------------------

void AocsEvent::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool AocsEvent::isConfigured()
{
	if (!AocsObject::isConfigured())
		return false;

	if ( (creator == NULL) || (timeStamp == 0) || (evtType == 0) )
		return false;

	return true;
}

// -------------------------------------------------------------------
// From Telemeterable interface

int AocsEvent::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}

// -------------------------------------------------------------------
// From Telemeterable interface
// Events do not call writeToTelemetry on their super object since they
// should only be written to telemetry by their repository

void AocsEvent::writeToTelemetry(TelemetryStream* tmStream)
{
	switch (getTelemetryFormat()) 
	{
		case debugTm :						// fall-through is intended!
		case longTm :
			tmStream->write(timeStamp);
			tmStream->write(creator->getInstanceId());
		case normalTm :
			tmStream->write(evtType);
	}
}
