// ChangeEventRepository.cpp
//
// Version	1.0
// Date		30.03.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/ChangeEventRepository.h"
#include "../AocsEvent/ChangeEvent.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventRepository.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------

ChangeEventRepository::ChangeEventRepository()
{
	setClassId(ID_CHANGEEVENTREPOSITORY);			// assign class identifier
	buffer = NULL;
}

// -------------------------------------------------------------------
// Allocate memory for the event buffer and for the list of event pointers.
// Load the pointer list with the addresses of the events in the buffer. 
// This method can only be called once.

void ChangeEventRepository::setRepositorySize(int n)
{
	if (buffer != NULL)			// method was already called!
	{	reportConfigurationError(this,MEMORY_ALREADY_ALLOCATED,this);
		return;
	}

	buffer = new ChangeEvent[n];
	EventRepository::setRepositorySize(n);	
	
	for (int i=0; i<n; i++)
		setList(i,&buffer[i]);
}

// -------------------------------------------------------------------
// Insert an event in the repository buffer

void ChangeEventRepository::create (AocsObject* creator, 
				  				      EventType evtType,
										PropertyId propertyId, 
										  ChangeObject* changeObject,
											Real value)
{
	// Insert new event in the buffer
	ChangeEvent* evt = (ChangeEvent*) insert();		
	evt->initialize(creator,evtType,propertyId,changeObject,value);	
}

// -------------------------------------------------------------------
// Return pointer to most recently stored event.

ChangeEvent* ChangeEventRepository::latestChangeEvent()
{
	return (ChangeEvent*)EventRepository::latest();
}

// -------------------------------------------------------------------
// Method to iterate through the events in the list

ChangeEvent* ChangeEventRepository::previousChangeEvent()
{
	return (ChangeEvent*)EventRepository::previous();
}

