// EventTypeId.h
//
// Version	1.0
// Date		07.02.00
// Author	A. Pasetti/T. Brown
//
// -------------------------------------------------------------------
// Definition of event type identifiers
// -------------------------------------------------------------------

#ifndef EventTypeIdH
#define EventTypeIdH

// -------------------------------------------------------------------

#define DUMMY_EVENT					1		// Dummy event, for test purposes only
#define DUMMY_EVENT_1				2		// Dummy event, for test purposes only
#define DUMMY_EVENT_2				3		// Dummy event, for test purposes only
#define DUMMY_EVENT_3				4		// Dummy event, for test purposes only
#define DUMMY_EVENT_4				5		// Dummy event, for test purposes only

#define CONFIG_ERROR				6		// Generic configuration error

#define ILLEGAL_FACTORY_PAR			7		// Illegal parameter passed to a factory method

#define UNCONFIGURED_RW				8		// Attempt to call the factory method for
											// the RwSet when the RW units are not yet
											// configured

#define UNCONFIGURED_SAP			9		// Attempt to call the factory method for
											// the THU unit when the SAP unit is not yet
											// configured

#define MISSING_FR_MM				10		// Attempt to construct the failure recovery
											// manager before constructing its mode
											// manager

#define MISSING_UNITS				11		// Attempt to construct the trigger lists
											// before constructing the AOCS units

#define MISSING_TRIGGER_LIST		12		// Attempt to construct the unit trigger mode
											// manager before constructing the trigger lists

#define MISSING_TRIGGER_MM			13		// Attempt to construct the unit triggers
											// manager before constructing the trigger 
											// mode manager

#define MISSING_TM_MM				14		// Attempt to construct the telemetry
											// manager before constructing its mode
											// manager

#define MISSING_FD_MM				15		// Attempt to construct the failure detection
											// manager before constructing its mode
											// manager

#define MISSING_CONT_MM				16		// Attempt to construct the controller
											// manager before constructing its mode
											// manager

#define ILLEGAL_MANOEUVRE			17		// Request to a manoeuvre factory for 
											// a non-existent manoeuvre object

#define NO_MEMORY_ALLOCATED			20		// Attempt to call a method which requires
											// memory to be previously allocated when
											// the memory has not been allocated

#define MEMORY_ALREADY_ALLOCATED	21		// Attempt to call a memory allocation
											// method twice

#define AOCS_OBJECT_DESTRUCTION		22		// An instance of AocsObject has been
											// destroyed

#define ILLEGAL_DATA_ITEM_ACCESS	30		// Attempt to retrieve an out-of-range 
											// data item in an AocsData	

#define ILLEGAL_PROPERTY_ACCESS		31		// Attempt to retrieve an out-of-range 
											// property in an AocsData	

#define NOT_DATA_ITEM_OWNER			32		// Illegal attempt to gain write-access
											// to a data item in an AocsData

#define INCOMPATIBLE_DATA_ITEMS		40		// Attempt to perform metrics operation
											// on data of different formats

#define ILLEGAL_PROPAGATION_TIME	50		// Attempt to call 'propagate' on a control
											// channel with a target time earlier than
											// the current output validity time

#define NON_EXISTENT_INPUT			51		// Attempt to link to a non-existent input
											// in a control channel block

#define NON_EXISTENT_OUTPUT			52		// Attempt to access a non-existent output
											// in a control channel block
#define NON_CONFIGURED_INPUT		53		// The input of a super block is not linked

#define XMATH_UCB_ERROR				60		// Error reported by UCB routine

#define LIST_IS_FULL				70		// Attempt to add an object to an object
											// list that is already full

#define OBJECT_NOT_IN_LIST			71		// Attempt to remove a non-existent object
											// from an object list

#define MONITORED_PROPERTY_CHANGE	80		// A change in a monitored property object
											// has occured

#define OPERATIONAL_MODE_CHANGE		90		// A change in operational mode has occured

#define ILLEGAL_MODE				91		// Attempt to use an illegal operational mode 

#define ILLEGAL_STRATEGY			92		// Attempt to use an illegal strategy

#define ILLEGAL_STRATEGY_OR_MODE	93		// Attempt to use an illegal strategy or an 
											// illegal mode 

#define MASTER_MODE_MNG_ALREADY_SET	94		// Attempt to set a master mode manager twice

#define TOO_MANY_TM_DATA			100		// The TM data do not fit in the TM buffer 

#define ILLEGAL_MEMORY_SECTION		101		// Attempt to define a memory section with 
											// starting address larger or equal to its 
											// end address

#define ILLEGAL_TM_LIST				102		// Attempt to access a non-existent TM list

#define TOO_MANY_SYSTEM_OBJECTS		110		// Attempt to register too many objects with
											// the system manager

#define TOO_MANY_RECONFIGURABLE		111		// Attempt to register too many reconfigurable
											// objects with the system manager

#define SYSTEM_RESET				112		// A system reset has been performed


#define MONITORING_CHECK_FAILURE	120		// A monitoring check failure has been detected
											// by the failure detection manager
	 

#define CONSISTENCY_CHECK_FAILURE	121		// A consistency check failure has been detected
											// by the failure detection manager

#define LOCAL_RECOVERY_ACTION		130		// A recovery action has been performed by 
											// the LocalRecoveryActions recovery strategy

#define SYSTEM_RESET_RECOVERY		131		// A system reset was performed by the 
											// SystemResetOnTooManyFailures recovery 
											// strategy

#define MISSING_RECOVERY_ACTION		132		// A failure event was found with no associated
											// recovery action

#define RECONFIG_ALREADY_CONFIG		133		// Illegal configuration attempt on a 
											// Configuration recovery action

#define MODE_CHANGE_ALREADY_CONFIG	134		// Illegal configuration attempt on a 
											// ModeChange recovery action

#define ILLEGAL_HK_CONVERTER		140		// Attempt to load a housekeeping converter in
											// an AOCS unit with incorrect number of inputs
											// or outputs

#define ILLEGAL_FC_CONVERTER		141		// Attempt to load a functional converter in
											// an AOCS unit with incorrect number of inputs
											// or outputs

#define ILLEGAL_HK_DEST_BUF			142		// Illegal housekeeping data destination buffer

#define ILLEGAL_FC_DEST_BUF			143		// Illegal functional data destination buffer

#define ILLEGAL_FC_SOURCE_BUF		144		// Illegal functional data source buffer

#define ILLEGAL_HW_BUF				145		// Attempt to access a non-existent hw buffer
											// in an AocsUnit

#define NO_BUS_TRANSMISSION			146		// The hw unit objec reported an error when
											// attempting to perform a bus transaction

#define NO_IN_CONVERTER				147		// Attempt to set a converter for incoming unit
											// data or a link to a destination buffer in
											// a unit that only has outgoing data

#define MISSING_FC_OUT_CONV			148		// Missing functional out converter in an AOCS
											// unit

#define ILLEGAL_ON_TIME_LINK		149		// Illegal attempt to link an on-time buffer
											// to a TorquingThruster unit

#define ILLEGAL_DELAY_TIME_LINK		150		// Illegal attempt to link a delay-time buffer
											// to a TorquingThruster unit

#define RECONFIGURATION				160		// A reconfiguration has taken place

#define RECONFIGURATION_FAILURE		161		// A reconfiguration was commanded but could
											// not be executed

#define ILLEGAL_CONFIGURATION		162		// Attempt to operate on a non-existent configuration

#define NO_MORE_CONFIGURATION		163		// No more free configuration availabled

#define ILLEGAL_RW_SPEED_LINK		164		// Attempt to link a rw reconfiguration manager
											// to a non-existent rw speed data item

#define ILLEGAL_RW_TORQUE_LINK		165		// Attempt to link a rw reconfiguration manager
											// to a non-existent rw torque data item

#define TC_SUCCESS					170		// TC executed successfully

#define TC_FAILURE					171		// TC execution failed

#define TC_TRANS_SUCCESS			172		// TC transaction executed successfully

#define TC_TRANS_FAILURE			173		// TC transaction failed but was successfully
											// unexecuted

#define TC_TRANS_UNDO_FAILURE		174		// TC transaction failed and its unexecution
											// failed

#define TC_LOADED					175		// TC was loaded into TC manager

#define TC_UNLOADED					176		// TC was unloaded from TC manager without
											// having been executed

#define TC_LIST_FULL				177		// The TC loader attempted to load a new TC
											// but the TC list was already full

#define TC_STACK_OVERFLOW			178		// Overflow of the internal TC manager stack 

#define TC_STACK_UNDERFLOW			179		// Underflow of the internal TC manager stack 

#define TC_BUFFER_OVERFLOW			180		// The length of the TC packet exceeds the 
											// size of the TC buffer

#define TC_OUT_OF_MEMORY			181		// A memory request by the TC loaded could
											// not be satisfied

#define TC_NOT_FOUND				182		// A request to release the memory allocated
											// to a TC failed because the TC could not be
											// found

#define TOO_MANY_MANOEUVRES			190		// Attempt to add more manoeuvres than the 
											// manoeuvre manager can handle

#define MANOEUVRE_NOT_IN_LIST		191		// Attempt to remove a manoeuvre that isn't in
											// the manoeuvre manager's current list

#define INVALID_MANOEUVRE_REMOVAL	192		// Attempt to remove a manoeuvre that cannot be
											// removed

#define INVALID_MANOEUVRE_HOLD		193		// Attempt to hold a manoeuvre that cannot be
											// put on hold

#define INVALID_MANOEUVRE_RESUME	194		// Attempt to resume a manoeuvre that cannot be
											// resumed (presumably because it is not on hold)

#define TOO_MANY_MANOEUVRE_MONITORS	195		// Attempt to add more manoeuvre monitors for
											// a manoeuvre than it can handle

#define UNKNOWN_MANOEUVRE_STATE		196		// Attempt to run a manoeuvre that is in an unknown
											// (i.e. undefined) state.  This is most likely 
											// a programming error.

#define MANOEUVRE_STARTED			197		// A manoeuvre was started

#define MANOEUVRE_TERMINATED		198		// A manoeuvre was terminated

#define MANOEUVRE_HELD				199		// A manoeuvre was put on hold

#define MANOEUVRE_RESUMED			200		// An on hold manoeuvre was resumed

#define MANOEUVRE_MON_NOT_IN_LIST	201		// Attempt to remove a manoeuvre monitor that 
											// is not in the monitor list

#define CONTROLLER_NOT_STABLE       202     // ControllerManager discovers unstable controller

// -------------------------------------------------------------------
#endif
