// FailureEventRepository.cpp
//
// Version	1.0
// Date		08.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/FailureEventRepository.h"
#include "../AocsEvent/FailureEvent.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventRepository.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------
// Default constructor.

FailureEventRepository::FailureEventRepository()
{
	setClassId(ID_FAILUREEVENTREPOSITORY);			// assign class identifier
	buffer = NULL;
}

// -------------------------------------------------------------------
// Allocate memory for the event buffer and for the list of event pointers.
// Load the pointer list with the addresses of the events in the buffer. 
// This method can only be called once.

void FailureEventRepository::setRepositorySize(int n)
{
	if (buffer != NULL)			// method was already called!
	{	reportConfigurationError(this,MEMORY_ALREADY_ALLOCATED,this);
		return;
	}

	buffer = new FailureEvent[n];
	EventRepository::setRepositorySize(n);	
	
	for (int i=0; i<n; i++)
		setList(i,&buffer[i]);
}

// -------------------------------------------------------------------
// Insert an event in the repository buffer

void FailureEventRepository::create (AocsObject* creator, 
									   EventType evtType,
										 AocsObject* failureLocation,
										   RecoveryAction* recoveryAction)
{
	FailureEvent* evt = (FailureEvent*) insert();		// insert new event
	evt->initialize(creator,evtType,failureLocation,recoveryAction);	// initialize new event
}

// -------------------------------------------------------------------
// Return pointer to most recently stored event.

FailureEvent* FailureEventRepository::latestFailureEvent()
{
	return (FailureEvent*)EventRepository::latest();
}

// -------------------------------------------------------------------
// Method to iterate through the events in the list

FailureEvent* FailureEventRepository::previousFailureEvent()
{
	return (FailureEvent*)EventRepository::previous();
}

