// ManoeuvreEvent.cpp
//
// Version  1.0
// Date     21.Jul.2000
// Author   T. Brown
//
// -------------------------------------------------------------------

#include "../AocsEvent/ManoeuvreEvent.h"
#include "../ManoeuvreManagement/Manoeuvre.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../TelemetryManagement/TelemetryStream.h"
#include "../FailureRecovery/RecoveryAction.h"


// -------------------------------------------------------------------
// Define static variables
int ManoeuvreEvent::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------
// Default constructor.
ManoeuvreEvent::ManoeuvreEvent()
{
	setClassId(ID_MANOEUVREEVENT);			// assign class identifier

	tmImageLength[shortTm]  = 0;
	tmImageLength[normalTm] = 0;
	tmImageLength[longTm]   = 8*sizeof(InstanceId);
	tmImageLength[debugTm]  = 8*sizeof(InstanceId);
	
	localResetConfiguration();				// reset object's configuration
}

// -------------------------------------------------------------------

void ManoeuvreEvent::initialize(AocsObject* creator, 
				  				EventType evtType,
								Manoeuvre* m) 
{
	AocsEvent::initialize(creator, evtType);
	manoeuvre = m;
}

// -------------------------------------------------------------------

void ManoeuvreEvent::localResetConfiguration()
{
	manoeuvre = NULL;
}

// -------------------------------------------------------------------
// From Configurable interface
void ManoeuvreEvent::resetConfiguration()
{
	AocsEvent::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool ManoeuvreEvent::isConfigured()
{
	if (!AocsEvent::isConfigured())
		return false;

	if (manoeuvre == NULL)
		return false;

	return true;
}

// -------------------------------------------------------------------
// From Telemeterable interface
int ManoeuvreEvent::getTelemetryImageLength()
{
	return AocsEvent::getTelemetryImageLength() +		
		   tmImageLength[getTelemetryFormat()];
}

// -------------------------------------------------------------------
void ManoeuvreEvent::writeToTelemetry(TelemetryStream* tmStream) 
{
	AocsEvent::writeToTelemetry(tmStream);   // write super object's state
	if ( (getTelemetryFormat()==longTm)	|| (getTelemetryFormat()==debugTm) ) 
	{
		tmStream->write(manoeuvre->getInstanceId());
	}

	return;
}
