// ManoeuvreEventRepository.cpp
// 
// Version  1.0
// Date     26.Jul.2000
// Author   T. Brown
//
// -------------------------------------------------------------------

#include "../AocsEvent/ManoeuvreEventRepository.h"
#include "../AocsEvent/ManoeuvreEvent.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventRepository.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------

ManoeuvreEventRepository::ManoeuvreEventRepository()
{
	setClassId(ID_MANOEUVREEVENTREPOSITORY);
	buffer = NULL;
}

// -------------------------------------------------------------------
void ManoeuvreEventRepository::setRepositorySize(int n)
{
	// This method can only be called once.
	if (buffer != NULL)		// method was already called!
	{
		reportConfigurationError(this, MEMORY_ALREADY_ALLOCATED, this);
		return;
	}

	// Allocate memory for the event buffer
	buffer = new ManoeuvreEvent[n];

	// Allocate memory for the list of event pointers
	EventRepository::setRepositorySize(n);

	// Load the pointer list with the addresses of the events in the buffer.
	for (int i=0; i<n; i++)
	{
		setList(i, &buffer[i]);
	}
}

// -------------------------------------------------------------------
// Insert an event in the repository buffer
ManoeuvreEvent* ManoeuvreEventRepository::create(
	AocsObject* creator, 
	EventType evtType, 
	Manoeuvre* associatedManoeuvre)
{
	// ManoeuvreEvent* evt = static_cast<ManoeuvreEvent*>(insert());
	ManoeuvreEvent* evt = (ManoeuvreEvent*) insert();		// insert new event
	evt->initialize(creator, evtType, associatedManoeuvre);
	return evt;
}

// -------------------------------------------------------------------
// Return pointer to most recently stored event.
ManoeuvreEvent* ManoeuvreEventRepository::latestManoeuvreEvent() 
{
	return (ManoeuvreEvent*) latest();
}

// -------------------------------------------------------------------
// Method to iterate through the events in the list
ManoeuvreEvent* ManoeuvreEventRepository::previousManoeuvreEvent()
{
	return (ManoeuvreEvent*) previous();
}
