// ModeEvent.cpp
//
// Version	1.0
// Date		01.04.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/ModeEvent.h"
#include "../AocsEvent/AocsEvent.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../TelemetryManagement/TelemetryStream.h"
#include "../ModeManagement/ModeManager.h"

// -------------------------------------------------------------------
// Define static variables
int ModeEvent::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------
// Default constructor.

ModeEvent::ModeEvent()
{
	setClassId(ID_MODEEVENT);			// assign class identifier

	tmImageLength[shortTm]  = 8*sizeof(unsigned char);		
	tmImageLength[normalTm] = tmImageLength[shortTm]+8*sizeof(InstanceId);	
	tmImageLength[longTm]   = tmImageLength[normalTm];
	tmImageLength[debugTm]  = tmImageLength[longTm];
	
	localResetConfiguration();			// reset object's configuration

}

// -------------------------------------------------------------------

void ModeEvent::initialize(AocsObject* creator, 
							   EventType evtType,
								 int oldM, 
								   int newM,
									 ModeManager* modeMan) 
{
	AocsEvent::initialize(creator, evtType);
	oldMode = oldM;
	newMode = newM;
	modeManager = modeMan;
}

// -------------------------------------------------------------------

void ModeEvent::localResetConfiguration()
{
	modeManager = NULL;
	oldMode = 0;
	newMode = 0;
}

// -------------------------------------------------------------------

void ModeEvent::resetConfiguration()
{
	AocsEvent::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool ModeEvent::isConfigured()
{
	if (!AocsEvent::isConfigured())
		return false;

	if ( ( modeManager == NULL ) || (oldMode == newMode) ) 
		return false;

	return true;
}

// -------------------------------------------------------------------
// From Telemeterable interface

int ModeEvent::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsEvent::getTelemetryImageLength());
}

// -------------------------------------------------------------------
// Only normal and long TM formats are implemented 

void ModeEvent::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsEvent::writeToTelemetry(tmStream);		// write super object's state

	// Combine old and new mode in a single byte (assume that the mode
	// indicator is in the range 0-15)
	unsigned char mode = (unsigned char)getOldMode();
	mode = mode << 4;
	mode = mode + (unsigned char)getNewMode();

	// Write the mode word and the instance ID of the mode manager
	tmStream->write((unsigned char)mode);
	tmStream->write((InstanceId)(getModeManager()->getInstanceId()));
}