// ModeEvent.h
//
// Version	1.0
// Date		29.03.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Class for mode events. 
//
// -------------------------------------------------------------------

#ifndef ModeEventH
#define ModeEventH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../AocsEvent/AocsEvent.h"

// -------------------------------------------------------------------

class ModeEvent : public AocsEvent {

	// The mode event records a change in mode (from 'oldMode' to 'newMode')
	// in the mode manager 'modeManager'
	unsigned char oldMode;						
	unsigned char newMode;						
	ModeManager* modeManager;

	static int tmImageLength[NTMFORMATS];

	void localResetConfiguration();		

public :

	ModeEvent();

	void initialize(AocsObject* creator, 
					  EventType evtType,
						int oldMode, 
						  int newMode,
							ModeManager* modeManager);

	unsigned char getOldMode()
		{ return oldMode; }

	unsigned char getNewMode()
		{ return newMode; }

	ModeManager* getModeManager()
		{ return modeManager; }

	virtual void resetConfiguration();	// pure virtual methods from Configurable	
	virtual bool isConfigured();		

										// pure virtual methods from Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual int getTelemetryImageLength();
};

// -------------------------------------------------------------------
#endif
