// ReconfigurationEventRepository.cpp
//
// Version	1.0
// Date		26.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/ReconfigurationEventRepository.h"
#include "../AocsEvent/ReconfigurationEvent.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventRepository.h"
#include "../AocsEvent/EventTypeId.h"


// -------------------------------------------------------------------

ReconfigurationEventRepository::ReconfigurationEventRepository()
{
	setClassId(ID_RECONFIGURATIONEVENTREPOSITORY);			
	buffer = NULL;
}

// -------------------------------------------------------------------
// Allocate memory for the event buffer and for the list of event pointers.
// Load the pointer list with the addresses of the events in the buffer. 
// This method can only be called once.

void ReconfigurationEventRepository::setRepositorySize(int n)
{
	if (buffer != NULL)			// method was already called!
	{	reportConfigurationError(this,MEMORY_ALREADY_ALLOCATED,this);
		return;
	}

	buffer = new ReconfigurationEvent[n];
	EventRepository::setRepositorySize(n);	
	
	for (int i=0; i<n; i++)
		setList(i,&buffer[i]);
}

// -------------------------------------------------------------------
// Insert an event in the repository buffer

void ReconfigurationEventRepository::create(AocsObject* creator, 
											  EventType evtType,
											    ConfigurationId oldConfig,
												  ConfigurationId newConfig,
											        InstanceId configManId)
{
	ReconfigurationEvent* evt = (ReconfigurationEvent*) insert();		
	evt->initialize(creator,evtType,oldConfig,newConfig,configManId);	
}

// -------------------------------------------------------------------
// Return pointer to most recently stored event.

ReconfigurationEvent* ReconfigurationEventRepository::latestModeEvent()
{
	return (ReconfigurationEvent*)EventRepository::latest();
}

// -------------------------------------------------------------------
// Method to iterate through the events in the list

ReconfigurationEvent* ReconfigurationEventRepository::previousModeEvent()
{
	return (ReconfigurationEvent*)EventRepository::previous();
}



