// RecoveryEventRepository.cpp
//
// Version	1.0
// Date		08.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/RecoveryEventRepository.h"
#include "../AocsEvent/RecoveryEvent.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventRepository.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------

RecoveryEventRepository::RecoveryEventRepository()
{
	setClassId(ID_RECOVERYEVENTREPOSITORY);			
	buffer = NULL;
}

// -------------------------------------------------------------------
// Allocate memory for the event buffer and for the list of event pointers.
// Load the pointer list with the addresses of the events in the buffer. 
// This method can only be called once.

void RecoveryEventRepository::setRepositorySize(int n)
{
	if (buffer != NULL)			// method was already called!
	{	reportConfigurationError(this,MEMORY_ALREADY_ALLOCATED,this);
		return;
	}

	buffer = new RecoveryEvent[n];
	EventRepository::setRepositorySize(n);	
	
	for (int i=0; i<n; i++)
		setList(i,&buffer[i]);
}

// -------------------------------------------------------------------
// Insert an event in the repository buffer

void RecoveryEventRepository::create (AocsObject* creator, 
									   EventType evtType,
										RecoveryAction* recAction,
										 RecoveryStrategy* recStrategy)
{
	RecoveryEvent* evt = (RecoveryEvent*) insert();			// insert new event
	evt->initialize(creator,evtType,recAction,recStrategy);	// initialize new event
}

// -------------------------------------------------------------------
// Return pointer to most recently stored event.

RecoveryEvent* RecoveryEventRepository::latestRecoveryEvent()
{
	return (RecoveryEvent*)EventRepository::latest();
}

// -------------------------------------------------------------------
// Method to iterate through the events in the list

RecoveryEvent* RecoveryEventRepository::previousRecoveryEvent()
{
	return (RecoveryEvent*)EventRepository::previous();
}



