// SystemEventRepository.cpp
//
// Version	1.0
// Date		13.04.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../AocsEvent/SystemEventRepository.h"
#include "../AocsEvent/SystemEvent.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------
// Default constructor.

SystemEventRepository::SystemEventRepository()
{
	setClassId(ID_SYSTEMEVENTREPOSITORY);			// assign class identifier
	buffer = NULL;
}

// -------------------------------------------------------------------
// Allocate memory for the event buffer and for the list of event pointers.
// Load the pointer list with the addresses of the events in the buffer. 
// This method can only be called once.

void SystemEventRepository::setRepositorySize(int n)
{
	if (buffer != NULL)			// method was already called!
	{	reportConfigurationError(this,MEMORY_ALREADY_ALLOCATED,this);
		return;
	}

	buffer = new SystemEvent[n];
	EventRepository::setRepositorySize(n);	
	
	for (int i=0; i<n; i++)
		setList(i,&buffer[i]);
}

// -------------------------------------------------------------------
// Insert an event in the repository buffer

void SystemEventRepository::create (EventType evtType)
{
	SystemEvent* evt = (SystemEvent*) insert();		// insert new event
	evt->initialize((AocsObject*)NULL,evtType);		// initialize new event
}

// -------------------------------------------------------------------
// Return pointer to most recently stored event.

SystemEvent* SystemEventRepository::latestSystemEvent()
{
	return (SystemEvent*)EventRepository::latest();
}

// -------------------------------------------------------------------
// Method to iterate through the events in the list

SystemEvent* SystemEventRepository::previousSystemEvent()
{
	return (SystemEvent*)EventRepository::previous();
}

