// MonitoringFactory.h
//
// Version	1.0
// Date		14.09.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Factory Class for the Object Monitoring Framelet.
//
// This class should be customized (by inheritance) for each AOCS
// application.
//
// The factory produces the change objects that are used to monitor
// framework variables. For each type of change objects, a dedicated
// factory method is provided, The change objects are always returned 
// as references to the base class ChangeObject.
//
// -------------------------------------------------------------------

#ifndef MonitoringFactoryH
#define MonitoringFactoryH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"

// -------------------------------------------------------------------

class MonitoringFactory {

public:

	MonitoringFactory();	

	ChangeObject* makeSimpleChange(Real referenceValue);

	ChangeObject* makeDeltaChange(Real referenceValue);

	ChangeObject* makeOutOfRangeChange(Real lowerBound, Real higherBound);
};

#endif
