// SystemFactory.h
//
// Version	1.0
// Date		14.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// AOCS System Factory Class: exposes methods to generate the AOCS 
// system manager and the AOCS system infrastructure (data pools,
// event repositories, and mission mode manager).
// This class should be customized (by inheritance) for each AOCS
// application.
// -------------------------------------------------------------------

#ifndef SystemFactoryH
#define SystemFactoryH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../ModeManagement/AocsMissionModeManager.h"

// -------------------------------------------------------------------

class SystemFactory {

	// Event Repositories
	SystemEventRepository*			systemEvtRep;
	FailureEventRepository*			failureEvtRep;
	ConfigurationEventRepository*	configEvtRep;
	ModeEventRepository*			modeEvtRep;
	ChangeEventRepository*			changeEvtRep;
	ReconfigurationEventRepository*	reconfigurationEvtRep;
	RecoveryEventRepository*		recoveryEvtRep;
	TelecommandEventRepository*		telecommandEvtRep;
	ManoeuvreEventRepository*		manoeuvreEvtRep;

	// System Manager
	SystemManager*					systemManager;

	// Data Pools
	AttitudeDataPool*				attitudeDataPool;

	// Mission Mode Manager
	AocsMissionModeManager*			missionModeManager;

public:

	SystemFactory();	

	// Construct the system components
	void makeEventRepositories();
	void makeAocsClock();
	void makeMissionModeManager(ModeChangeAction* mca);
	void makeSystemManager();
	void makeDataPools(RecoveryAction* consistencyCheckFailure);

	// Return the event repositories
	SystemEventRepository*	getSystemEventRepository()
		{ return systemEvtRep; }
	FailureEventRepository*	getFailureEventRepository()
		{ return failureEvtRep; }
	ConfigurationEventRepository* getConfigurationEventRepository()
		{ return configEvtRep; }
	ModeEventRepository* getModeEventRepository()
		{ return modeEvtRep; }
	ChangeEventRepository* getChangeEventRepository()
		{ return changeEvtRep; }
	ReconfigurationEventRepository* getReconfigurationEventRepository()
		{ return reconfigurationEvtRep; }
	TelecommandEventRepository* getTelecommandEventRepository()
		{ return telecommandEvtRep; }
	RecoveryEventRepository* getRecoveryEventRepository()
		{ return recoveryEvtRep; }
	ManoeuvreEventRepository* getManoeuvreEventRepository()
		{ return manoeuvreEvtRep; }

	// Return the data pools
	AttitudeDataPool* getAttitudeDataPool()
		{ return attitudeDataPool; }

	// Return the mission mode manager
	ModeManager* getMissionModeManager()
		{ return missionModeManager; }

	// Return the system manager
	SystemManager* getSystemManager()
		{ return systemManager; }

	// Return the AOC clock
	AocsClock* getAocsClock()
		{ return AocsObject::getAocsClock();}
};

#endif
