// TelemetryFactory.h
//
// Version	1.0
// Date		14.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Factory Class for Telemetry Framelet.
//
// This class should be customized (by inheritance) for each AOCS
// application.
//
// -------------------------------------------------------------------

#ifndef TelemetryFactoryH
#define TelemetryFactoryH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../TelemetryManagement/DmaTelemetryStream.h"

// -------------------------------------------------------------------

class TelemetryFactory {

	TelemetryManager* tmManager;
	TelemetryModeManager* tmModeManager;
	DmaTelemetryStream* tmStream;

	ObjectListTemplate<Telemeterable>** tmListArray;

	// Start address of the TM DMA buffer (either the real one or a 
	// simulated buffer created internally
	char* tmDmaBufferStart;

	// Size of DMA TM buffer in number of bytes
	int tmBufferSize;

protected:

	virtual void makeTelemetryLists();

public:

	TelemetryFactory();	

	// Construct and configure the TM mode manager
	virtual void makeTelemetryModeManager(ModeChangeAction* mca);

	// Construct and configure the TM manager
	virtual void makeTelemetryManager();

	// Construct and configure the TM stream.
	// A DMA TM stream is assumed and the parameters are the size and
	// starting address of the DMA buffer where TM is to be stored.
	// The TM buffer size is expressed in bytes.
	virtual void makeTelemetryStream(int tmBufferSize, char* tmDmaStart);

	// Retrieve a TM list
	ObjectListTemplate<Telemeterable>* getTelemetryList(int mode);

	// Getter methods 
	TelemetryManager* getTelemetryManager()
		{ return tmManager; }
	TelemetryModeManager* getTelemetryModeManager()
		{ return tmModeManager; }
	TelemetryStream* getTelemetryStream()
		{ return tmStream; }
	int getTelemetryBufferSize()
		{ return tmBufferSize; }
	char* getTelemetrydDmaBufferStart()
		{ return tmDmaBufferStart; }
};

#endif
