// AocsPrototypeTest.h
//
// Version	1.0
// Date		16.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#ifndef AocsPrototypeTestH
#define AocsPrototypeTestH

// -------------------------------------------------------------------

#include <stdio.h>  
#include "../AocsFactory/SystemFactory.h"
#include "../AocsFactory/TelemetryFactory.h"
#include "../AocsFactory/TelecommandFactory.h"
#include "../AocsFactory/AocsUnitFactory.h"
#include "../AocsFactory/FailureRecoveryFactory.h"
#include "../AocsFactory/FailureDetectionFactory.h"
#include "../AocsFactory/MonitoringFactory.h"
#include "../AocsFactory/ModeFactory.h"
#include "../AocsFactory/ManoeuvreFactory.h"
#include "../AocsFactory/ControllerFactory.h"

// -------------------------------------------------------------------
// Define structure to hold framework factory references

struct FrameworkFactories {
	SystemFactory*				systemFactory;
	TelemetryFactory*			telemetryFactory;
	TelecommandFactory*			telecommandFactory;
	AocsUnitFactory*			aocsUnitFactory;
	FailureRecoveryFactory*		failureRecoveryFactory;
	FailureDetectionFactory*	failureDetectionFactory;
	MonitoringFactory*			monitoringFactory;
	ModeFactory*				modeFactory;
	ManoeuvreFactory*			manoeuvreFactory;
	ControllerFactory*			controllerFactory;
};

// -------------------------------------------------------------------
#define N_AOCS_TASKS		20
#define N_AOCS_CYCLES		10
#define TM_SAVE				10
#define MACS_SAVE			10

// -------------------------------------------------------------------
// Number of MACS hardware buffers holding outgoing data (4 RW torques
// + 6 THU_A delay times + 6 THU_A on-time times + 6 THU_B delay times 
// + 6 THU_B on-time times)
#define N_MACS_OUT_HW_BUF	28

// -------------------------------------------------------------------
// Define initialization routines
void instantiateAocs(FILE* out, FrameworkFactories fwFact);
void loadTelemetryLists(FrameworkFactories fwFact);
void loadControllerLists(FrameworkFactories fwFact);
void loadFailureDetectionLists(FrameworkFactories fwFact);
void loadUnitTriggerLists(FrameworkFactories fwFact);
void makeSystemComponents(FrameworkFactories fwFact);
void makeUnits(FrameworkFactories fwFact);
void makeTelemetryComponents(FrameworkFactories fwFact);
void makeControllerComponents(FrameworkFactories fwFact);
void makeFailureRecoveryComponents(FrameworkFactories fwFact);
void makeFailureDetectionComponents(FrameworkFactories fwFact);
void makeUnitTriggers(FrameworkFactories fwFact);
void makeTelecommandComponents(FrameworkFactories fwFact);
void makeManoeuvreComponents(FrameworkFactories fwFact);

class AocsTestHarness;	// forward declaration

#endif
