// AocsTestHarness_1.h
//
// Version	1.0
// Date		03.08.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// This class implements the following test scenario:
//	- two telecommands are sent to the AOCS sw:
//	  . TC1 is sent in the fourth cycle. It is a TC transaction 
//		consisting of two simple TC's: the first one changes the 
//		operational mode of mission mode manager to FPM; the second 
//		one reconfigures the FSS.
//	  . TC2 is sent in the sixth cycle. It is a simple TC to 
//		reconfigure the FSS.
//
//	- two sets of actuator commands are generated. The first set is:
//		scTor = (1.0, 2.0, 3.0)
//	   the second set is obtained from the first one by changing the
//	   sign.
//	   A toggle variable is used to switch between the two sets in 
//	   each AOCS cycle.
//
//	- two sets of sensor data are loaded. The first set is:
//		FSS = (1024, 1024)
//		GYR = 2048
//		RW_SPEED = (2,4,6,8)
//		SAS1 = (3072, 3072)
//		SAS2 = (3072, 3072)
//		SAS3 = (3072, 3072)
//	   the second set is obtained from the first one by changing the
//	   sign.
//	   A toggle variable is used to switch between the two sets in 
//	   each AOCS cycle.
// -------------------------------------------------------------------

#ifndef AocsTestHarness_1H
#define AocsTestHarness_1H

// -------------------------------------------------------------------

#include <stdio.h>  
#include "../AocsPrototypeTest/AocsTestHarness.h"
#include "../AocsPrototypeTest/AocsPrototypeTest.h"

// -------------------------------------------------------------------

class AocsTestHarness_1 : public AocsTestHarness {

	// Variables to control the generation of actuator commands
	int cmdToggle;

	// Variables to control the simulated inputs from MACS units
	int macsToggle;
	unsigned short macsBase;
	unsigned short rwBase;

	// Counts number of time loadTelecommands() was entered
	int tcCycleCounter;

protected:

	// Write the telecommands to the telecommand buffer
	virtual void loadTelecommands();

	// Write the TC transaction
	void loadTelecommandTransaction();

	// Write the simple TC 
	void loadSimpleTelecommand();

	// Write MACS data to the input hardware buffer
	virtual void loadMacs();

	// Generate a set of actuator commands
	virtual void generateActuatorCommands();

public:

	AocsTestHarness_1(FrameworkFactories fwFact, FILE* out);
};

// -------------------------------------------------------------------
#endif