// AocsTestHarness_2.h
//
// Version	1.0
// Date		14.09.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// This class implements the following test scenario:
//	- three telecommands are sent to the AOCS sw:
//	  . TC1 is sent in the third cycle. It is a simple TC to start
//		an attitude slew manoeuvre.
//	  . TC2 is sent in the fourth cycle. It is a TC transaction 
//		consisting of two simple TC's: the first one changes the 
//		operational mode of mission mode manager to FPM; the second 
//		one reconfigures the FSS.
//	  . TC3 is sent in the sixth cycle. It is a simple TC to 
//		reconfigure the FSS.
//
//	- The sensors are stimulated to simulate the following scenario:
//	  . at test start, the s/c has its z-axis sun-pointing
//	  . the angular rate around the x-axis is: w_x = 0.0002 rad/sec
//	  . in the seventh cycle a gyro error is simulated that brings
//		its output to a value corresponding to 0.1 rad/sec
//	  . All sensors are assumed to be ideal, except for FSS B that
//		has a 10% scaling factor error
//
//	- The reaction wheel speed are set to 0
//
// -------------------------------------------------------------------

#ifndef AocsTestHarness_2H
#define AocsTestHarness_2H

// -------------------------------------------------------------------

#include <stdio.h>  
#include "../AocsPrototypeTest/AocsTestHarness.h"
#include "../AocsPrototypeTest/AocsPrototypeTest.h"

// -------------------------------------------------------------------

class AocsTestHarness_2 : public AocsTestHarness {

	// X-axis angular rate
	Real w_x;

	// Counts number of time loadTelecommands() was entered
	int tcCycleCounter;

	// Counts number of time loadMacs() was entered
	int macsCycleCounter;

protected:

	// Write the telecommands to the telecommand buffer
	virtual void loadTelecommands();

	// Write the TC transaction
	void loadTelecommandTransaction();

	// Write the TC to reconfigure the FSS
	void loadFssReconfigureTelecommand();

	// Write the TC to start the attitude slew manoeuvre
	void loadSlewManoeuvreTelecommand();

	// Write MACS data to the input hardware buffer
	virtual void loadMacs();

	// Generate a set of actuator commands
	virtual void generateActuatorCommands();

public:

	AocsTestHarness_2(FrameworkFactories fwFact, FILE* out);
};

// -------------------------------------------------------------------
#endif