/*  RtemsTest.c
 *	
 *  Simple RTEMS test. An initialization task starts a periodic
 *  tasks that simply prints a message.
 *
 */

// Include system header files
#include <stdio.h>  

// Include framework header files
#include "../GeneralInclude/Include.h"
#include "../TelemetryManagement/Telemeterable.h"
#include "../BasicObjects/Include.h"
#include "../OperatingSystemObjects/Include.h"
#include "../FailureDetection/ConsistencyCheckable.h"
#include "../ObjectList/Include.h"
#include "../AocsData/Include.h"
#include "../ObjectMonitoring/Include.h"
#include "../AocsEvent/Include.h"
#include "../ModeManagement/Include.h"
#include "../FailureRecovery/Include.h"
#include "../FailureDetection/Include.h"
#include "../Xmath/Include.h"
#include "../SequentialDataProcessing/Include.h"
#include "../AocsUnit/Include.h"
#include "../TelemetryManagement/Include.h"
#include "../TelecommandManagement/Include.h"
#include "../ReconfigurationManagement/Include.h"
#include "../ManoeuvreManagement/Include.h"
//#include "../BasicObjects/RootObjectTest/RootObjectTestSuite.h"

// Include the AOCS factory and AOCS configuration headers
#include "../AocsFactory/Include.h"

// Include test header files
#include "../GeneralUtilities/TestUtilities.h"
#include "AocsPrototypeTest.h"
#include "AocsTestHarness.h"

/* Include file for rtems environment */

#include <tmacros.h>

/* Specify C linkage for initialization routine (called by rtems exec) */

extern "C" {
   rtems_task Init( rtems_task_argument argument);
   rtems_task Test_task(rtems_task_argument unused);
}

/* rtems configuration information (inherited from RTEMS sample) */

#define TEST_INIT
#define CONFIGURE_SPTEST

#define CONFIGURE_TEST_NEEDS_CONSOLE_DRIVER
#define CONFIGURE_TEST_NEEDS_CLOCK_DRIVER

#define CONFIGURE_RTEMS_INIT_TASKS_TABLE
#define CONFIGURE_INIT

/* rtems configuration information (added for this test) */

#define CONFIGURE_INIT_TASK_STACK_SIZE 2*RTEMS_MINIMUM_STACK_SIZE

#define CONFIGURE_INIT_TASK_ATTRIBUTES RTEMS_FLOATING_POINT

#include <confdefs.h>

/* global variables */

rtems_id   Rtems_Task_id[ 4 ];         /* array of task ids */
rtems_name Rtems_Task_name[ 4 ];       /* array of task names */

/* Initialization task for this test program called from init_exec */

rtems_task Init(rtems_task_argument argument)
{
  rtems_status_code status;
  rtems_time_of_day time;

  // Print header message to output stream
  FILE* out=NULL;
  printTestHeader(out,"AocsPrototypeTest");

  // Initialize RTEMS time
  build_time( &time, 01, 01, 1999, 9, 0, 0, 0 );
  status = rtems_clock_set( &time );

  // Define the structure to hold the AOCS tasks
  Runnable* aocsTasks[N_AOCS_TASKS];

  // Construct framework factories and initialize factory structure
  SystemFactory* systemFactory = new SystemFactory;
  TelemetryFactory* telemetryFactory = new TelemetryFactory;
  struct FrameworkFactories fwFact;
  fwFact.systemFactory=systemFactory;

  // Initialize AOCS software
//  instantiateAocs(out, fwFact);

  // Create the test harness task
// AocsTestHarness_2 aocsTestHarness(fwFact);

  // load the structure holding the AOCS tasks
  for (int k=0; k<N_AOCS_TASKS; k++)
	aocsTasks[k] = NULL;
  aocsTasks[0] = telemetryFactory->getTelemetryManager();
//  aocsTasks[N_AOCS_TASKS-1] = &aocsTestHarness;

  // Create the RTEMS task to execute the AOCS tasks
  Rtems_Task_name[ 1 ] = rtems_build_name( 'T', 'A', '1', ' ' );

  status = rtems_task_create(
    Rtems_Task_name[ 1 ], 1, RTEMS_MINIMUM_STACK_SIZE, RTEMS_DEFAULT_MODES,
//    RTEMS_DEFAULT_ATTRIBUTES, &Rtems_Task_id[ 1 ]
    RTEMS_FLOATING_POINT, &Rtems_Task_id[ 1 ]
  );

  // Start the RTEMS task to execute the AOCS tasks
  status = rtems_task_start( Rtems_Task_id[ 1 ], Test_task, 1 );

//  rootObjectTestMaster((FILE*)0);

  status = rtems_task_delete( RTEMS_SELF );

//  puts( "\n\n*** End of C++ Interface Test ***" );

}
/*-------------------------------------------------------------------------*/
rtems_task Test_task(rtems_task_argument unused)
{
  rtems_id          tid;
  rtems_time_of_day time;
  rtems_unsigned32  task_index;
  rtems_status_code status;

  status = rtems_task_ident( RTEMS_SELF, RTEMS_SEARCH_ALL_NODES, &tid );
  task_index = task_number( tid );
  while( FOREVER ) {
    status = rtems_clock_get( RTEMS_CLOCK_GET_TOD, &time );
    if ( time.second >= N_AOCS_CYCLES) {
      puts( "*** END OF CLOCK TICK TEST ***" );
      exit( 0 );
    }
    put_name( Rtems_Task_name[ task_index ], FALSE );
    print_time( " - rtems_clock_get - ", &time, "\n" );
    status = rtems_task_wake_after( task_index * 5 * TICKS_PER_SECOND );
  }
}
