// TestCaseAocsUnit_5.cpp
//
// Version	1.0
// Date		03.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseAocsUnit_5.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/TwoEulerAngles.h"
#include "../../AocsData/DataItemWrite.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../AocsEvent/ConfigurationEvent.h"
#include "../../AocsEvent/SystemEvent.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../AocsEvent/FailureEventRepository.h"
#include "../../AocsEvent/ConfigurationEventRepository.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../SequentialDataProcessing/TwoByTwoMatrixBlock.h"
#include "../../SequentialDataProcessing/RawBusDataConverterIn.h"
#include "../../SequentialDataProcessing/RawBusDataConverterOut.h"
#include "../../SequentialDataProcessing/BiasScalingCompensator.h"
#include "../../SequentialDataProcessing/ControlChannelSuperBlock.h"
#include "../../AocsUnit/MacsTcController.h"
#include "../../AocsUnit/GyrPrototype.h"
#include "../../FailureRecovery/NullRecoveryAction.h"

// -------------------------------------------------------------------
TestCaseAocsUnit_5::TestCaseAocsUnit_5():
	TestCaseGenericSetUp(ID_UNITTRIGGER*10+5,
									"TestCaseAocsUnit_5") {
		return;
}

// -------------------------------------------------------------------

void TestCaseAocsUnit_5::runTestCase() {

	// Retrieve the number of failure and configuration events
	int fen = AocsObject::getFailureEventRepository()->getCounter();
	int cen = AocsObject::getConfigurationEventRepository()->getCounter();

	// The following locations represent the MACS registers
	short macsCs=0;
	short macsInstr=0;
	short macsData=0;

	// Create and configure the MACS TC object
	MacsTcController macsTcCont(&macsCs, &macsInstr, &macsData);
	macsTcCont.setMaxPolling(2);

	// Create the raw data converter for the GYR rate measurement
	RawBusDataConverterIn convIn(1,0.2);

	// Create the bias and scaling factor converter for the GYR rate measurement
	BiasScalingCompensator bsc(4.0,2.0);

	// Link the raw data converter and the bias/scaling compensator
	bsc.linkInput(&convIn,0,0);

	// Create and configure the converter superblock for the GYR
	ControlChannelSuperBlock gyrConv(1,1);
	gyrConv.linkInputInternal(&convIn,0,0);
	gyrConv.linkOutputInternal(&bsc,0,0);

	// Create a dummy recovery action
	NullRecoveryAction recAct;

	// Create destination buffer for GYR measurements and its time tag
	Real rate;
	AocsTime rateTTag;
	DataItemWrite rateDiw(&rateTTag, &rate);

	// Create and configure the GYR object
	GyrPrototype gyr(10,11);
	gyr.setAocsUnitHardware(&macsTcCont);
	gyr.setFunctionalInConverter(&gyrConv);
	gyr.setFunctionalInLink(rateDiw,0);
	gyr.setHwFailureRecoveryAction(&recAct);

	// Check that the GYR object is configured
	if (!gyr.isConfigured())
	{	setTestResult(TEST_FAILURE, "Aocs Unit test 5 failed");
		return;
	}

	// Acquire the GYR measurement. Since there is no real external unit, one
	// bus error should be generated. The MACS control register should reflect 
	// the last instruction put on the bus
	gyr.acquireFunctionalData();
	if (macsInstr!=-29866)			// -29866 = 0x8B56		
	{	setTestResult(TEST_FAILURE, "Aocs Unit test 5 failed");
		return;
	}
	if (AocsObject::getFailureEventRepository()->getCounter() != fen+1)
	{	setTestResult(TEST_FAILURE, "Aocs Unit test 5 failed");
		return;
	}

	// Simulate acquisition of rate measurement from the GYR
	unsigned short rawRate = 0x8030;

	gyr.setFcHwInpBuff(rawRate,0);
	gyr.refreshFunctionalIn();
	if ( (rate < 23.1) || (rate > 23.3) )
	{	setTestResult(TEST_FAILURE, "Aocs Unit test 5 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}




