// FullTriggerList.cpp
//
// Version	1.0
// Date		02.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"
#include "../BasicObjects/AocsObject.h"
#include "../AocsUnit/FullTriggerList.h"		

// -------------------------------------------------------------------
// Define static variables
int FullTriggerList::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------

FullTriggerList::FullTriggerList(int hkSyn, int hkAcq, int fcSyn, 
								 int fcAcq, int fcSnd, int hkIni)
{
	tmImageLength[shortTm]  = 0;	// Not implemented in fw prototype	
	tmImageLength[normalTm] = 0;
	tmImageLength[longTm]   = 0;
	tmImageLength[debugTm]  = 0;

	setClassId(ID_TRIGGERLIST);	

	hkSynch.allocateMemory(hkSyn);
	hkAcquire.allocateMemory(hkAcq);
	fcSynch.allocateMemory(fcSyn);
	fcAcquire.allocateMemory(fcAcq);
	fcSend.allocateMemory(fcSnd);
	hkInit.allocateMemory(hkIni);

	localResetConfiguration();
	localReset();
}

// -------------------------------------------------------------------

void FullTriggerList::localReset()
{
	hkSynch.reset();
	hkAcquire.reset();
	fcSynch.reset();
	fcAcquire.reset();
	fcSend.reset();
	hkInit.reset();
}
	
// -------------------------------------------------------------------

void FullTriggerList::localResetConfiguration()
{
	hkSynch.resetConfiguration();
	hkAcquire.resetConfiguration();
	fcSynch.resetConfiguration();
	fcAcquire.resetConfiguration();
	fcSend.resetConfiguration();
	hkInit.resetConfiguration();
}	

// -------------------------------------------------------------------

void FullTriggerList::reset()
{
	AocsObject::reset();
	localReset();
}


// -------------------------------------------------------------------

void FullTriggerList::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool FullTriggerList::isConfigured()
{
	if (!AocsObject::isConfigured())
		return false;

	if (!hkSynch.isConfigured())
		return false;

	if (!hkAcquire.isConfigured())
		return false;

	if (!fcSynch.isConfigured())
		return false;

	if (!fcAcquire.isConfigured())
		return false;

	if (!fcSend.isConfigured())
		return false;

	if (!hkInit.isConfigured())
		return false;

	return true;
}

// -------------------------------------------------------------------

void FullTriggerList::initialize()
{
	for (AocsUnitHousekeeping* unit = hkInit.first(); 
			!hkInit.isLast();
				unit = hkInit.next())
	{
		unit->switchOn();
		unit->initialize();
	}
}

// -------------------------------------------------------------------

void FullTriggerList::shutdown()
{
	for (AocsUnitHousekeeping* unit = hkInit.first(); 
			!hkInit.isLast();
				unit = hkInit.next())
		unit->switchOff();
}

// -------------------------------------------------------------------

void FullTriggerList::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsObject::writeToTelemetry(tmStream);		// write super object's state

	// not implemented in framework prototype
}

// -------------------------------------------------------------------

int FullTriggerList::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}
