// MacsTcController.cpp
//
// Version	1.0
// Date		27.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../GeneralInclude/ClassId.h"
#include "../AocsUnit/MacsTcController.h"

// -------------------------------------------------------------------

MacsTcController::MacsTcController(short* c, short* i, short* d)
{
	setClassId(ID_MACSTCCONTROLLER);			

	MacsCs = c;
	MacsInstr = i;
	MacsData = d;

	resetInterface();
}

// -------------------------------------------------------------------
// Reset MACS controller by setting RESET bit of MACS_CS register

void MacsTcController::resetInterface()
{
	*MacsCs |= RESET;	
}

// -------------------------------------------------------------------
// Reset MACS transaction by setting RESET bit of MACS_CS register

void MacsTcController::resetTransaction()
{
	*MacsCs |= RESET;
}

// -------------------------------------------------------------------
// Transaction is successful if parity error bit, ackonwledge error 
// bit, and error bit are not set in the MACS_CS register

bool MacsTcController::wasTransactionSuccessful()
{
	return ( ( (*MacsCs) & ERROR) > 0 );
}

// -------------------------------------------------------------------
// Transaction is finished if 'finished' bit in MACS_CS register is set

bool MacsTcController::isTransactionFinished()
{
	return ( ((*MacsCs) & FINISHED) > 0);
}

// -------------------------------------------------------------------

void MacsTcController::sendAndReturn(UnitInstruction instr)
{
	// Load instruction register
	*MacsInstr = 0;
	*MacsInstr = instr.priority;
	*MacsInstr |= (instr.destAddress<<3);
	*MacsInstr |= (instr.subAddress<<8);
	*MacsInstr |= (instr.command<<13);
	
	// Load data word (superfluous but harmless if command is a RD)
	*MacsData = *(instr.data);	

	// Clear 'finished' bit
	*MacsCs &= FINISHED_INV;

	// Initiate transaction
	*MacsCs |= SEND;
}

// -------------------------------------------------------------------

bool MacsTcController::sendAndWait(UnitInstruction instr)
{
	sendAndReturn(instr);

	// Poll MACS_CS register
	int n=0;
	while ( (n<maxPoll) && (((*MacsCs) & FINISHED)==0) ) 
		n++;

	return (n<maxPoll);
}
