// FssPrototype.cpp
//
// Version	1.0
// Date		29.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../AocsUnit/RwPrototype.h"			
#include "../AocsUnit/AocsUnitHardware.h"
#include "../AocsUnit/MacsConstants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventTypeId.h"				

// -------------------------------------------------------------------

RwPrototype::RwPrototype(unsigned short a, 
							unsigned short b, 
							 unsigned short c):
					AocsUnit(0,0,1,1,1,1)
{
	setClassId(ID_RWPROTOTYPE);			

	address = a;
	sa_speed = b;
	sa_torque = c;

}

// -------------------------------------------------------------------
// Send the MACS RC to initialize the MACS bus head of the RW

void RwPrototype::initialize()
{
	UnitInstruction instr={MACS_INSTR,address,1,MACS_RC,(unsigned short*)fcHwInpBuf,0};
	if (!hwUnit->sendAndWait(instr))
		reportFailure(this,NO_BUS_TRANSMISSION,this,hwFailureRecAct);
	return;
}

// -------------------------------------------------------------------
// Send a MACS TI instruction to the subaddresses identifying the 
// the RW speed channel. 

void RwPrototype::acquireFunctionalData()
{
	UnitInstruction instr;
	
	instr.priority = MACS_INSTR;
	instr.destAddress = address;
	instr.subAddress = sa_speed;
	instr.command = MACS_TI;
	instr.data=(unsigned short*)&fcHwInpBuf[0];

	if (!hwUnit->sendAndWait(instr))		
		reportFailure(this,NO_BUS_TRANSMISSION,this,hwFailureRecAct);

	return;
}

// -------------------------------------------------------------------
// Send a MACS RD instruction to the subaddresses identifying the 
// the RW torque request channel. 

void RwPrototype::sendFunctionalData()
{
	UnitInstruction instr;
	
	instr.priority = MACS_INSTR;
	instr.destAddress = address;
	instr.subAddress = sa_torque;
	instr.command = MACS_RD;
	instr.data=(unsigned short*)&fcHwOutBuf[0];

	if (!hwUnit->sendAndWait(instr))		
		reportFailure(this,NO_BUS_TRANSMISSION,this,hwFailureRecAct);

	return;
}





