// SapPrototype.cpp
//
// Version	1.0
// Date		31.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../AocsUnit/SapPrototype.h"			
#include "../AocsUnit/AocsUnitHardware.h"
#include "../AocsUnit/MacsConstants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventTypeId.h"				

// -------------------------------------------------------------------

SapPrototype::SapPrototype(unsigned short a, 
							unsigned short b,
							 unsigned short c):
					AocsUnit(0,0,6,6,12,12)
{
	setClassId(ID_SAPPROTOTYPE);			

	address = a;
	sasBaseSubaddress = b;
	thuBaseSubaddress = c;
}

// -------------------------------------------------------------------
// Send the MACS RC to initialize the MACS bus head of the SAP unit

void SapPrototype::initialize()
{
	UnitInstruction instr={MACS_INSTR,address,1,MACS_RC,(unsigned short*)fcHwInpBuf,0};
	if (!hwUnit->sendAndWait(instr))
		reportFailure(this,NO_BUS_TRANSMISSION,this,hwFailureRecAct);
	return;
}

// -------------------------------------------------------------------
// Send 6 MACS TI instructions to the subaddresses identifying the 
// SAS outputs. The relevant subaddress are 'sasBaseSubaddress' to 
// 'sasBaseSubaddress+6'. 

void SapPrototype::acquireFunctionalData()
{
	UnitInstruction instr;
	
	instr.priority = MACS_INSTR;
	instr.destAddress = address;
	instr.command = MACS_TI;

	for (int i=0; i<6; i++)
	{	instr.subAddress = sasBaseSubaddress+i;
		instr.data=(unsigned short*)&fcHwInpBuf[i];

		if (!hwUnit->sendAndWait(instr))		
			reportFailure(this,NO_BUS_TRANSMISSION,this,hwFailureRecAct);
	}

	return;
}

// -------------------------------------------------------------------
// Send 12 MACS RD instructions to the subaddresses identifying the 
// THU inputs. The relevant subaddress are 'thuBaseSubaddress' to 
// 'thuBaseSubaddress+12'. 

void SapPrototype::sendFunctionalData()
{
	UnitInstruction instr;
	
	instr.priority = MACS_INSTR;
	instr.destAddress = address;
	instr.command = MACS_RD;

	for (int i=0; i<12; i++)
	{	instr.subAddress = thuBaseSubaddress+i;
		instr.data=(unsigned short*)&fcHwOutBuf[i];

		if (!hwUnit->sendAndWait(instr))		
			reportFailure(this,NO_BUS_TRANSMISSION,this,hwFailureRecAct);
	}

	return;
}



