// SapPrototype.h
//
// Version	1.0
// Date		31.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Class for the AOCS prototype encapsulating the interface to the
// sun acquisition and propulsion electronis unit.
//
// The SAP unit controls 3 Sun Acquisition Sensors (SAS's) and 6 
// thrusters (THU).
// Each SAS outputs two sun position measurements.
// Each thruster can receive two data inputs the delay time and the 
// on-time.
//
// The SAP unit can receive the following MACS instructions:
//	- RC command to initialize the MACS bus head
//	- TI commands to acquire the SAS outputs
//	- RD commands to receive the THU delay times
//	- RD commands to receive the THU on-time
//
// The inputs to the SAP unit are ordered as follows:
//	- input i for i=1..6: delay-time for i-th thruster
//	- input i for i=7..12: on-time for i-th thruster
//
// The outputs from the SAP unit are ordered as follows:
//	- output 1: SAS 1 X channel read-out
//	- output 2: SAS 1 Y channel read-out
//	- output 3: SAS 2 X channel read-out
//	- output 4: SAS 2 Y channel read-out
//	- output 5: SAS 3 X channel read-out
//	- output 6: SAS 3 Y channel read-out
//	
// -------------------------------------------------------------------

#ifndef SapPrototypeH
#define SapPrototypeH

// -------------------------------------------------------------------

#include "../AocsUnit/AocsUnit.h"

// -------------------------------------------------------------------

class SapPrototype : public AocsUnit {

	unsigned short address;
	unsigned short sasBaseSubaddress;
	unsigned short thuBaseSubaddress;

public:

	SapPrototype(unsigned short address,
					unsigned short sasBaseSubaddress,
					   unsigned short thuBaseSubaddress);

	virtual void initialize();

	virtual void acquireFunctionalData();

	virtual void sendFunctionalData();
};

// -------------------------------------------------------------------
#endif