// TriggerList.h
//
// Version	1.0
// Date		08.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Interface class for trigger lists
// -------------------------------------------------------------------

#ifndef TriggerListH
#define TriggerListH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"

// -------------------------------------------------------------------

class TriggerList {

public:

	// Add/Remove items from the lists of units to be triggered
	virtual void addHousekeepingSynchronize(AocsUnitHousekeeping* unitToBeSynchronized)=0;

	virtual void addHousekeepingAcquire(AocsUnitHousekeeping* unitToBeTriggered)=0;
	
	virtual void addFunctionalSynchronize(AocsUnitFunctional* unitToBeSynchronized)=0;

	virtual void addFunctionalAcquire(AocsUnitFunctional* unitToBeTriggered)=0;

	virtual void addFunctionalSend(AocsUnitFunctional* unitToBeTriggered)=0;

	virtual void removeHousekeepingSynchronize(AocsUnitHousekeeping* unitToBeSynchronized)=0;

	virtual void removeHousekeepingAcquire(AocsUnitHousekeeping* unitToBeTriggered)=0;
	
	virtual void removeFunctionalSynchronize(AocsUnitFunctional* unitToBeSynchronized)=0;

	virtual void removeFunctionalAcquire(AocsUnitFunctional* unitToBeTriggered)=0;

	virtual void removeFunctionalSend(AocsUnitFunctional* unitToBeTriggered)=0;

	// Iterate through units to which hk synchronization message must be sent
	virtual AocsUnitHousekeeping* firstHousekeepingSynchronize()=0;
	virtual AocsUnitHousekeeping* nextHousekeepingSynchronize()=0;
	virtual bool isLastHousekeepingSynchronize()=0;

	// Iterate through units from which hk data must be acquired
	virtual AocsUnitHousekeeping* firstHousekeepingAcquire()=0;
	virtual AocsUnitHousekeeping* nextHousekeepingAcquire()=0;
	virtual bool isLastHousekeepingAcquire()=0;

	// Iterate through units to which fc synchronization messages must be sent
	virtual AocsUnitFunctional* firstFunctionalSynchronize()=0;
	virtual AocsUnitFunctional* nextFunctionalSynchronize()=0;
	virtual bool isLastFunctionalSynchronize()=0;

	// Iterate through units from which fc data must be acquired
	virtual AocsUnitFunctional* firstAcquireFunctional()=0;
	virtual AocsUnitFunctional* nextAcquireFunctional()=0;
	virtual bool isLastAcquireFunctional()=0;

	// Iterate through units to which fc data must be sent
	virtual AocsUnitFunctional* firstSendFunctional()=0;
	virtual AocsUnitFunctional* nextSendFunctional()=0;
	virtual bool isLastSendFunctional()=0;

	// Add/Remove items from the lists of units to be initialized/shutdown
	virtual void addInitShutdownUnit(AocsUnitHousekeeping* initShutdownUnit)=0;
	virtual void removeInitShutdownUnit(AocsUnitHousekeeping* initShutdownUnit)=0;

	// Initialize and shut-down operations for the units in the trigger list
	virtual void initialize()=0;
	virtual void shutdown()=0;
};

// -------------------------------------------------------------------
#endif