// UnitTrigger.h
//
// Version	1.0
// Date		02.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Encapsulation of unit trigger object.
// This unit trigger carries out the bus transaction and refresh phases
// in sequence. It therefore assumes that the operations in the bus 
// transaction phase are of the blocking kind (ie. they return only 
// the bus transaction has actually been terminated).  
// -------------------------------------------------------------------

#ifndef UnitTriggerH
#define UnitTriggerH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../BasicObjects/AocsObject.h"
#include "../OperatingSystemObjects/Runnable.h"

// -------------------------------------------------------------------

class UnitTrigger : public AocsObject, public Runnable {

	static int tmImageLength[NTMFORMATS];

	UnitTriggerModeManager* modeManager;
		
	// Local reset methods
	void localResetConfiguration();		

public:

	UnitTrigger();

	// Scheduler entry point
	virtual void run(AocsTime deadline);

	// Virtual methods inherited from interface Configurable
	virtual void resetConfiguration();
	virtual bool isConfigured();
	
	// Virtual methods inherited from interface Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual int getTelemetryImageLength();

	// Straightforward getter and setter methods
	void setUnitTriggerModeManager(UnitTriggerModeManager* mm)
		{ modeManager = mm; }
	UnitTriggerModeManager* getUnitTriggerModeManager()
		{ return modeManager; }

};

// -------------------------------------------------------------------
#endif