// AocsObject.h
//
// Version	1.0
// Date		13.01.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#ifndef AocsObjectH
#define AocsObjectH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../BasicObjects/RootObject.h"
#include "../BasicObjects/Resettable.h"
#include "../BasicObjects/Configurable.h"
#include "../TelemetryManagement/Telemeterable.h"

// -------------------------------------------------------------------

class AocsObject: public RootObject, 
					public Resettable, 
					  public Configurable,
					    public Telemeterable {			

	static AocsClock* aocsClock;
	static FailureEventRepository* failureEvtRep;
	static ConfigurationEventRepository* configEvtRep;
	static SystemManager* systemManager;
	static RecoveryAction* aocsDestructionRecAct;

	static int tmImageLength[NTMFORMATS];
	TelemetryFormat currentTmFormat;

protected :

	void reportFailure(AocsObject* creator, 
					     EventType failureType,
					       AocsObject* location, 
					          RecoveryAction* recoveryAction);

	void reportConfigurationError(AocsObject* creator, 
								    EventType configErrType,
								      AocsObject* location);

	AocsTime getTime();
		
	AocsCycle getCycle();

public :

	AocsObject();
	~AocsObject();

	// Straightforward getter and setter methods
	static void setAocsClock(AocsClock* c) 
			{aocsClock = c;}
	static AocsClock* getAocsClock() 
			{ return aocsClock;}

	static void setSystemManager(SystemManager* s) 
			{systemManager = s;}
	static SystemManager* getSystemManager() 
			{return systemManager;}

	static void setFailureEventRepository(FailureEventRepository* r) 
			{failureEvtRep = r;}
	static FailureEventRepository* getFailureEventRepository() 
			{return failureEvtRep;}

	static void setConfigurationEventRepository(ConfigurationEventRepository* r) 
			{configEvtRep = r;}
	static ConfigurationEventRepository* getConfigurationEventRepository() 
			{return configEvtRep;}

	static void setDestructionRecoveryAction(RecoveryAction* r) 
			{aocsDestructionRecAct = r;}
	static RecoveryAction* getDestructionRecoveryAction() 
			{return aocsDestructionRecAct;}

	static void resetStaticConfiguration();

	// Virtual methods inherited from interface Configurable
	virtual void reset();				

	// Virtual methods inherited from interface Configurable
	virtual void resetConfiguration();		
	virtual bool isConfigured();		

	// Virtual methods inherited from interface Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual void setTelemetryFormat(TelemetryFormat newFormat);
	virtual TelemetryFormat getTelemetryFormat();
	virtual int getTelemetryImageLength();

};

// -------------------------------------------------------------------
#endif