// TestCaseController_1.cpp
//
// Version	1.0
// Date		06.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseController_1.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsEvent/AocsEvent.h"
#include "../../SequentialDataProcessing/P_Block.h"
#include "../../FailureRecovery/NullRecoveryAction.h"
#include "../../ControllerManagement/Controller.h"

// -------------------------------------------------------------------
TestCaseController_1::TestCaseController_1():
	TestCaseGenericSetUp(ID_CONTROLLERMANAGER*10+1,
									"TestCaseController_1") {
		return;
}

// -------------------------------------------------------------------

void TestCaseController_1::runTestCase() {

    // Create a Controller
    Controller myController;

    // Create and load dummy instability recovery action
    NullRecoveryAction nra;
    myController.setInstabilityRecoveryAction(&nra);

    // Link required measurement input
    Real sensorInputData;
    sensorInputData = 17.0;
    DataItemRead sensorInput(&sensorInputData);
    myController.linkSensorMeasurement(sensorInput);

    // Do NOT link the Reference signal input
    // Do NOT link the Feedforward signal input

    // Link required actuator command output
    Real actuatorCommandOutputData;
    AocsTime outputTime;
    DataItemWrite actuatorCommandOutput(&outputTime, &actuatorCommandOutputData);
    myController.linkActuatorCommand(actuatorCommandOutput);

    // Do NOT link the compensator output
    // Do NOT link the control error output

    // Link required compensator transfer function
    P_Block myProportionalTransferBlock;
    myProportionalTransferBlock.setGain(0.5);
    myController.setCompensator(&myProportionalTransferBlock);

    // Ask the controller to do its job

    // Note: After the first request for the controller to
    // do its control function, if the clock has not advanced
    // then doControl() will not cause its outputs to change
    // because the propagate() will have no effect on the
    // control blocks that are part of the controller.
    // So, as a matter of course in these tests, we always
    // advance the clock prior to asking the controller to
    // doControl().

    aocsClock.run(0);
    myController.doControl();

    // check actuator command output
    if (actuatorCommandOutputData != -8.5)
	{	setTestResult(TEST_FAILURE, "Controller test 1 failed");
		return;
	}

    // Ask again
    aocsClock.run(0);
    myController.doControl();

    // check actuator command output
    if (actuatorCommandOutputData != -8.5)
	{	setTestResult(TEST_FAILURE, "Controller test 1 failed");
		return;
	}

    // Change input and ask again
    sensorInputData = 600.0;
    aocsClock.run(0);
    myController.doControl();

    // check actuator command output
    if (actuatorCommandOutputData != -300.0)
	{	setTestResult(TEST_FAILURE, "Controller test 1 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}

