// FailureDetectionManager.h
//
// Version	1.0
// Date		07.04.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Failure detection manager class
// -------------------------------------------------------------------

#ifndef FailureDetectionManagerH
#define FailureDetectionManagerH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../BasicObjects/AocsObject.h"
#include "../OperatingSystemObjects/Runnable.h"
#include "../FailureDetection/ConsistencyCheckable.h"
#include "../FailureDetection/MonitoringCheck.h"

// -------------------------------------------------------------------

class FailureDetectionManager : public AocsObject, public Runnable {

	static int tmImageLength[NTMFORMATS];

	// List of objects upon which to perform consistency checks
	ObjectListTemplate<ConsistencyCheckable>* consistencyCheckableList;

	// List of monitoring checks
	ObjectListTemplate<MonitoringCheck>* monitoringCheckList;
	
	// Mode manager to supply consistency checkable and monitoring check lists
	FailureDetectionModeManager* modeManager;

	// Reference to change event repositories
	ChangeEventRepository* changeEventRepository;
	
	// Local reset configuration method
	void localResetConfiguration();

public:

	// Constructor
	FailureDetectionManager();

	// Scheduler entry point
	virtual void run(AocsTime deadline);

	// pure virtual methods from Configurable
	virtual void resetConfiguration();		
	virtual bool isConfigured();		
	
	// Virtual methods inherited from interface Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual int getTelemetryImageLength();

	// Straightforward getter and setter methods
	void setFailureDetectionModeManager(FailureDetectionModeManager* tmm)
		{ modeManager = tmm; }
	FailureDetectionModeManager* getFailureDetectionModeManager()
		{ return modeManager; }

	// Straightforward getter and setter methods
	void setChangeEventRepository(ChangeEventRepository* c)
		{ changeEventRepository = c; }
	ChangeEventRepository* getChangeEventRepository()
		{ return changeEventRepository; }

};

// -------------------------------------------------------------------
#endif