// FailureDetectionModeManager.h
//
// Version	1.0
// Date		05.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Interface class for the failure detection mode manager.
// The FD mode manager manages two strategies: the list of objects to be
// subjected to consistency check tests, and the list of monitoring check
// objects.
// -------------------------------------------------------------------

#ifndef FailureDetectionModeManagerH
#define FailureDetectionModeManagerH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../FailureDetection/ConsistencyCheckable.h"
#include "../FailureDetection/MonitoringCheck.h"

// -------------------------------------------------------------------

class FailureDetectionModeManager {

public :

	// Configuration method to load the implementers
	virtual void loadConsistencyCheckableList(int mode, ObjectListTemplate<ConsistencyCheckable>* l)=0;
	virtual void loadMonitoringCheckList(int mode, ObjectListTemplate<MonitoringCheck>* l)=0;

	// Strategy getter methods
	virtual ObjectListTemplate<ConsistencyCheckable>* getConsistencyCheckableList()=0;
	virtual ObjectListTemplate<MonitoringCheck>* getMonitoringCheckList()=0;

};

// -------------------------------------------------------------------
#endif
