// FailureRecoveryManager.cpp
//
// Version	1.0
// Date		07.04.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../FailureRecovery/FailureRecoveryManager.h"
#include "../FailureRecovery/FailureRecoveryModeManager.h"
#include "../FailureRecovery/RecoveryStrategy.h"
#include "../ModeManagement/ModeManager.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../AocsEvent/EventTypeId.h"
#include "../AocsEvent/ChangeEventRepository.h"
#include "../ObjectList/ObjectListTemplate.h"
#include "../ObjectMonitoring/ChangeObject.h"

// -------------------------------------------------------------------
// Define static variables
int FailureRecoveryManager::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------

FailureRecoveryManager::FailureRecoveryManager()
{
	setClassId(ID_FAILURERECOVERYMANAGER);	// assign class identifier

	tmImageLength[shortTm]  = 0;			// not implemented in f/w prototype
	tmImageLength[normalTm] = 0;
	tmImageLength[longTm]   = 0;
	tmImageLength[debugTm]  = 0;

	localResetConfiguration();
}

// -------------------------------------------------------------------

void FailureRecoveryManager::localResetConfiguration()
{
	modeManager = NULL;
}

// -------------------------------------------------------------------

void FailureRecoveryManager::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool FailureRecoveryManager::isConfigured()
{
	if (!AocsObject::isConfigured())
		return false;

	if (modeManager==NULL)
		return false;
	
	return true;
}

// -------------------------------------------------------------------

void FailureRecoveryManager::run(AocsTime deadline)
{
	// Load the recovery strategy
	RecoveryStrategy* recoveryStrategy = modeManager->getRecoveryStrategy();

	// Implement the recovery strategy
	recoveryStrategy->doRecovery();

}

// -------------------------------------------------------------------
// From Telemeterable interface

int FailureRecoveryManager::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}

// -------------------------------------------------------------------
// From Telemeterable interface

void FailureRecoveryManager::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsObject::writeToTelemetry(tmStream);		// write super object's state

	// TBD : not implemented in framework prototype
}
