// RecoveryAction.cpp
//
// Version	1.0
// Date		10.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../FailureRecovery/RecoveryAction.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------
// Define static variables
int RecoveryAction::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------

RecoveryAction::RecoveryAction()
{
	setClassId(ID_RECOVERYACTION);		

	tmImageLength[shortTm]  = 0;	// not implemented in f/w prototype
	tmImageLength[normalTm] = 0;
	tmImageLength[longTm]   = 0;
	tmImageLength[debugTm]  = 0;

	localResetConfiguration();
	localReset();
}

// -------------------------------------------------------------------

void RecoveryAction::doRecovery()
{
	if (nextRecoveryAction != NULL)
		nextRecoveryAction->doRecovery();
}	
	
// -------------------------------------------------------------------

void RecoveryAction::localReset()
{
	enabled = true;
}

// -------------------------------------------------------------------

void RecoveryAction::reset()
{
	AocsObject::reset();
	localReset();
}

// -------------------------------------------------------------------

void RecoveryAction::localResetConfiguration()
{
	nextRecoveryAction = NULL;
}

// -------------------------------------------------------------------

void RecoveryAction::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

int RecoveryAction::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}

// -------------------------------------------------------------------

void RecoveryAction::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsObject::writeToTelemetry(tmStream);		// write super object's state

	// TBD : not implemented in framework prototype
}
