// RecoveryStrategy.cpp
//
// Version	1.0
// Date		10.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../FailureRecovery/RecoveryStrategy.h"

// -------------------------------------------------------------------
// Define static variables
int RecoveryStrategy::tmImageLength[NTMFORMATS];
RecoveryEventRepository*		RecoveryStrategy::recoveryEventRepository=NULL;

// -------------------------------------------------------------------

RecoveryStrategy::RecoveryStrategy()
{
	setClassId(ID_RECOVERYSTRATEGY);		

	tmImageLength[shortTm]  = 0;	// not implemented in f/w prototype
	tmImageLength[normalTm] = 0;
	tmImageLength[longTm]   = 0;
	tmImageLength[debugTm]  = 0;

	localResetConfiguration();
	localReset();
}

// -------------------------------------------------------------------

void RecoveryStrategy::doRecovery()
{
	if (nextRecoveryStrategy != NULL)
		nextRecoveryStrategy->doRecovery();
}	
	
// -------------------------------------------------------------------

void RecoveryStrategy::localReset()
{
	enabled = true;
}

// -------------------------------------------------------------------

void RecoveryStrategy::reset()
{
	AocsObject::reset();
	localReset();
}

// -------------------------------------------------------------------

void RecoveryStrategy::localResetConfiguration()
{
	nextRecoveryStrategy = NULL;
}

// -------------------------------------------------------------------

void RecoveryStrategy::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

void RecoveryStrategy::resetStaticConfiguration()
{
	recoveryEventRepository=NULL;
}

// -------------------------------------------------------------------

bool RecoveryStrategy::isConfigured()
{
	if (!AocsObject::isConfigured())
		return false;

	if (recoveryEventRepository==NULL)
		return false;
	
	return true;
}

// -------------------------------------------------------------------

int RecoveryStrategy::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}

// -------------------------------------------------------------------

void RecoveryStrategy::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsObject::writeToTelemetry(tmStream);		// write super object's state

	// TBD : not implemented in framework prototype
}
