// FlushTelemetryBuffers.h 
//
// Version	1.0
// Date		31.07.00
// Author	A. Pasetti
// -------------------------------------------------------------------
//
// Utility routines to process the telemetry buffer.
// Routine FlushTelemetryBuffers processes all the TM buffers filled
// by the test harness. The other routines process the images of
// individual objects in a TM stream. 
// One routine is provided for each framework class that can 
// potentially be included in telemetry. The routine for class <class>
// is called flush<class>.
// The operations performed by the flush routines are the inverse of
// the operations performed by the writeToTelemetry method in the
// corresponding framework class.
// The TelemetryStreamOnGround object represents the TM streams as it
// seen by the ground software.
// The FILE parameter is the file to which the TM data are sent.
// The tmFormat parameter is the TM format of the image being read.
// This parameter is read from the TM stream by flushAocsObject and
// is used by other flush routines to decide which information to
// retrieve from the TM image.
//
// -------------------------------------------------------------------

#include <stdio.h>  
#include "../GeneralInclude/BasicTypes.h"
#include "../AocsPrototypeTest/DmaTelemetryStreamOnGround.h"
#include "../AocsPrototypeTest/AocsTestHarness.h"

// -------------------------------------------------------------------

// Send the content of the TM buffers collected by the test harness
// to the ooutput file 'out'
void flushTelemetryBuffers(FILE* out, AocsTestHarness* aocsTestHarness); 

void flushAocsObject(FILE* out, 
						DmaTelemetryStreamOnGround* stream, 
							TelemetryFormat* tmFormat);

void flushAocsEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushFailureEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushConfigurationEvent(FILE* out, 
								DmaTelemetryStreamOnGround* s, 
									TelemetryFormat* tmFormat);

void flushModeEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushSystemEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushReconfigurationEvent(FILE* out, 
								DmaTelemetryStreamOnGround* s, 
									TelemetryFormat* tmFormat);

void flushTelecommandEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushRecoveryEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushManoeuvreEvent(FILE* out, 
						DmaTelemetryStreamOnGround* s, 
							TelemetryFormat* tmFormat);

void flushEventRepository(FILE* out, 
							DmaTelemetryStreamOnGround* s, 
								TelemetryFormat* tmFormat,
									int* numberOfEvents);

void flushFailureEventRepository(FILE* out,
									DmaTelemetryStreamOnGround* s,
										TelemetryFormat* tmFormat,
											int* numberOfEvents);

void flushConfigurationEventRepository(FILE* out, 
										DmaTelemetryStreamOnGround* s, 
										 TelemetryFormat* tmFormat,
										  int* numberOfEvents);

void flushModeEventRepository(FILE* out, 
									DmaTelemetryStreamOnGround* s, 
										TelemetryFormat* tmFormat,
											int* numberOfEvents);

void flushReconfigurationEventRepository(FILE* out, 
										DmaTelemetryStreamOnGround* s, 
										 TelemetryFormat* tmFormat,
										  int* numberOfEvents);

void flushManoeuvreEventRepository(FILE* out, 
										DmaTelemetryStreamOnGround* s, 
										 TelemetryFormat* tmFormat,
										  int* numberOfEvents);

void flushSystemEventRepository(FILE* out, 
										DmaTelemetryStreamOnGround* s, 
										 TelemetryFormat* tmFormat,
										  int* numberOfEvents);

void flushTelecommandEventRepository(FILE* out, 
										DmaTelemetryStreamOnGround* s, 
										 TelemetryFormat* tmFormat,
										  int* numberOfEvents);

void flushRecoveryEventRepository(FILE* out, 
										DmaTelemetryStreamOnGround* s, 
										 TelemetryFormat* tmFormat,
										  int* numberOfEvents);

void flushAttitudeDataPool(FILE* out, 
							DmaTelemetryStreamOnGround* s, 
							 TelemetryFormat* tmFormat);

void flushDataPool(FILE* out, 
					DmaTelemetryStreamOnGround* s, 
					 TelemetryFormat* tmFormat);

void flushAocsData(FILE* out, 
					DmaTelemetryStreamOnGround* s, 
					 TelemetryFormat* tmFormat);
