// TestCase.h
//
// Version	1.0
// Date		12.12.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
//
// Abstract base class for all test cases.
//
// -------------------------------------------------------------------

#ifndef TestCaseH
#define TestCaseH

#define TEST_SUCCESS true		
#define TEST_FAILURE false

#define INITIALIZATION_SUCCESS true		
#define INITIALIZATION_FAILURE false

#define SHUTDOWN_SUCCESS true		
#define SHUTDOWN_FAILURE false

// -------------------------------------------------------------------

class TestCase {

	int testId;
	char* testName;
	bool testOutcome;
	char* failureMessage;

	bool testResultFlag;	// true if setTestResult was called

public :

	TestCase(int testId, char* testName);

	// To be called before the test starts. Returns false if 
	// initialization failed
	virtual bool setUpTestCase()=0;

	// To be called to execute the test
	virtual void runTestCase()=0;
	
	// To be called after test execution. Returns false if 
	// shut down failed
	virtual bool shutDownTestCase()=0;

	// Set the test result -- can only be called once!
	void setTestResult(bool outcome, char* failureMessage);

	// Getter methods
	char* getTestName()
		{ return testName; }

	bool getTestOutcome()
		{ return testOutcome; }

	char* getFailureMessage()
		{ return failureMessage; }
};

// -------------------------------------------------------------------

#endif