// TestCaseModeManagement_1.cpp
//
// Version	1.0
// Date		27.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseModeManagement_1.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../BasicObjects/RootObject.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../ModeManagement/CyclingModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"

// -------------------------------------------------------------------
TestCaseModeManagement_1::TestCaseModeManagement_1():
	TestCaseGenericSetUp(ID_MODEMANAGER*10+1,
									"TestCaseModeManagement_1") {
		return;
}

// -------------------------------------------------------------------

void TestCaseModeManagement_1::runTestCase() {

	// Create a cyclical mode manager
	int nModes=3;
	int nMonitors=4;
	int defaultMode=2;
	CyclingModeManager mm(nModes,defaultMode,nMonitors);

	// Create dummy objects to serve as dummy implementers
	RootObject dummy00,dummy01,dummy10,dummy11,dummy20,dummy21;

	// Check that the mode manager is not configured
	if (mm.isConfigured())
	{	setTestResult(TEST_FAILURE, "Mode manager configured");
		return;
	}
	
	// Load implementers
	mm.loadImplementer(0,0,&dummy00);
	mm.loadImplementer(1,0,&dummy10);
	mm.loadImplementer(2,0,&dummy20);

	// Load the mode change actions in the cycling mode manager
	NullModeChangeAction mca;
	mm.setModeChangeAction(&mca);

	// Check that no failure or configuration events have been created
	if ( failureEvtRep.getCounter() != failureEvtN )
	{	setTestResult(TEST_FAILURE, "Failure event was generated");
		return;
	}
	if ( configEvtRep.getCounter() != configEvtN )
	{	setTestResult(TEST_FAILURE, "Configuration event was generated");
		return;
	}

	// Check that the mode manager now is configured
	if (!mm.isConfigured())
	{	setTestResult(TEST_FAILURE, "Mode manager not configured");
		return;
	}

	// Attempt to load illegal strategies/mode
	mm.loadImplementer(2,2,&dummy00);
	mm.loadImplementer(3,1,&dummy00);

	// Check that no failure and 2 configuration events have been created
	if ( failureEvtRep.getCounter() != failureEvtN )
	{	setTestResult(TEST_FAILURE, "Failure event was generated");
		return;
	}
	if ( configEvtRep.getCounter() != configEvtN+2 )
	{	setTestResult(TEST_FAILURE, "Wrong number of configuratio events");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
