// TestCaseObjectList_3.cpp
//
// Version	1.0
// Date		07.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseObjectList_3.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../BasicObjects/AocsObject.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../AocsEvent/ConfigurationEvent.h"

// -------------------------------------------------------------------
TestCaseObjectList_3::TestCaseObjectList_3():
	TestCaseObjectList(ID_OBJECTLIST*10+3,"TestCaseObjectList_3") {
		return;
}

// -------------------------------------------------------------------

void TestCaseObjectList_3::runTestCase() {

	// Reset the configuration of the list (thus clearing all its entries)
	objectList.reset();
	objectList.resetConfiguration();

	// Check that there are no entries in the object list
	if (objectList.getNumberOfItems() != 0)
	{	setTestResult(TEST_FAILURE, "Object list should be empty");
		return;
	}

	// Check iteration through an empty list
	for (AocsObject* obj=objectList.first(); !objectList.isLast(); objectList.next())
	{	setTestResult(TEST_FAILURE, "Incorrect iteration through empty list");
		return;
	}

	// Create dummy objects to be added to the list 
	AocsObject dummy1, dummy2, dummy3;

	// Create and initialize an array to store identifiers of objects 
	// retrieved from the list
	int instanceIdArray[4];
	for (int j=0; j<4; j++)
		instanceIdArray[j]=0;

	// Perform some add/remove operations in sequence
	objectList.addObject(&dummy1);
	objectList.addObject(&dummy2);
	objectList.addObject(&dummy3);
	objectList.removeObject(&dummy2);

	// Perform iteration through the partially full list
	int i = 0;
	for (obj=objectList.first(); !objectList.isLast(); obj=objectList.next())
	{	instanceIdArray[i]=(int)obj->getInstanceId();
		i++;
	}

	// Check that the correct identifiers were retrieved
	if ( instanceIdArray[0] != dummy1.getInstanceId() )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	if ( instanceIdArray[1] != dummy3.getInstanceId() )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	if ( instanceIdArray[2] != 0 )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	// Fill up the list
	objectList.addObject(&dummy2);
	objectList.addObject(&dummy2);

	// Perform iteration through the full list
	i = 0; 
	for (obj=objectList.first(); !objectList.isLast(); obj=objectList.next())
	{	instanceIdArray[i]=(int)obj->getInstanceId();
		i++;
	}

	// Check that the correct identifiers were retrieved
	if ( instanceIdArray[0] != dummy1.getInstanceId() )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	if ( instanceIdArray[1] != dummy2.getInstanceId() )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	if ( instanceIdArray[2] != dummy3.getInstanceId() )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	if ( instanceIdArray[3] != dummy2.getInstanceId() )
	{	setTestResult(TEST_FAILURE, "Incorrect item in object list");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
