// TestCaseObjectMonitoring_1.cpp
//
// Version	1.0
// Date		23.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseObjectMonitoring_1.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../ObjectMonitoring/OutOfRangeChange.h"
#include "../../ObjectMonitoring/DeltaChange.h"
#include "../../ObjectMonitoring/SimpleChange.h"

// -------------------------------------------------------------------
TestCaseObjectMonitoring_1::TestCaseObjectMonitoring_1():
	TestCaseGenericSetUp(ID_SIMPLECHANGE*10+1,"TestCaseObjectMonitoring_1") {
		return;
}

// -------------------------------------------------------------------

void TestCaseObjectMonitoring_1::runTestCase() {

	// Create change objects
	Real reference = 4;
	SimpleChange simpleChange(reference);
	
	Real delta = 10;
	DeltaChange deltaChange(delta);

	Real lowerBound = 5;
	Real upperBound = 20;
	OutOfRangeChange outOfRangeChange(lowerBound, upperBound);

	// Check simple change object
	if (simpleChange.checkValue(reference))
	{	setTestResult(TEST_FAILURE, "Incorrect simple change check");
		return;
	}
	if (!simpleChange.checkValue(reference+1))
	{	setTestResult(TEST_FAILURE, "Incorrect simple change check");
		return;
	}

	// Check delta change object
	deltaChange.checkValue(1);

	if (deltaChange.checkValue(delta))
	{	setTestResult(TEST_FAILURE, "Incorrect delta change check");
		return;
	}

	if (deltaChange.checkValue(1))
	{	setTestResult(TEST_FAILURE, "Incorrect delta change check");
		return;
	}

	if (!deltaChange.checkValue(2*delta))
	{	setTestResult(TEST_FAILURE, "Incorrect delta change check");
		return;
	}

	// Check out-of-range change object
	if ( outOfRangeChange.checkValue((lowerBound+upperBound)/2) )
	{	setTestResult(TEST_FAILURE, "Incorrect out-of-range change check");
		return;
	}

	if ( !outOfRangeChange.checkValue(lowerBound-0.001) )
	{	setTestResult(TEST_FAILURE, "Incorrect out-of-range change check");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
