// RtemsAocsClock.h
//
// Version	1.0
// Date		15.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Implementation of AocsClock interface for ERC32 processor with 
// RTEMS operating system.
// -------------------------------------------------------------------

#ifndef RtemsAocsClockH
#define RtemsAocsClockH

// -------------------------------------------------------------------

#include "../GeneralInclude/CompilerSwitches.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../BasicObjects/AocsObject.h"
#include "../OperatingSystemObjects/AocsClock.h"

// -------------------------------------------------------------------
// In order to allow testing under VS: define RTEMS types and a dummy
// RTEMS timing routine

#ifdef MS_HOST
	typedef AocsTime rtems_interval;
	void rtems_clock_get(int ignored,AocsTime* ticks);
	#define RTEMS_CLOCK_GET_TICKS_SINCE_BOOT 1
#else
	#include <rtems.h> 
#endif

// -------------------------------------------------------------------

class RtemsAocsClock : public AocsObject, public AocsClock {

	AocsCycle cyclesAtLastReset;		// Cycles when object was last reset
	unsigned int ticksPerCycle;			// RTEMS ticks in an AOCS cycle

	static ClassId classId;
	static int tmImageLength[NTMFORMATS];

	void localReset();
	void localResetConfiguration();

public :

	RtemsAocsClock(unsigned int ticksPerCycle);

	virtual AocsTime getTime();				// from AocsClock
	virtual AocsCycle getCycle();
	virtual void synchronizeWithSystemTime();

	virtual void reset();					// from Resettable through AocsObject

	virtual void resetConfiguration();		// from Configurable through AocsObject
	virtual bool isConfigured();

	virtual int getTelemetryImageLength();	// from Telemeterable through AocsObject
	virtual void writeToTelemetry(TelemetryStream* stream);

	// Straightforward getter and setter methods
	void setTicksPerCycle(unsigned int tpc)
		{ ticksPerCycle = tpc; }
};

// -------------------------------------------------------------------
#endif