// BasicUnitReconfigurer.cpp
//
// Version	1.0
// Date		28.06.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../ReconfigurationManagement/BasicUnitReconfigurer.h"
#include "../ReconfigurationManagement/ReconfigurerHelper.h"
#include "../AocsUnit/AocsUnit.h"
#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../AocsEvent/EventTypeId.h"	


// -------------------------------------------------------------------
// Define static variables
int BasicUnitReconfigurer::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------

BasicUnitReconfigurer::BasicUnitReconfigurer(int nOfUnits, 
											  int nOfMon,
											   ConfigurationId defConfig)
{
	setClassId(ID_BASICUNITRECONFIGURER);				

	tmImageLength[shortTm]  = 0;		// Not implemented in fw prototype
	tmImageLength[normalTm] = 0;	
	tmImageLength[longTm]   = tmImageLength[normalTm];
	tmImageLength[debugTm]  = tmImageLength[longTm];

	helper = new ReconfigurerHelper(nOfUnits,nOfMon,defConfig,this);

	unit = new AocsUnit*[nOfUnits];

	// All configurations have the same rank
	for (int i=0; i<nOfUnits; i++)
		helper->rankConfiguration(i,1);
	
}

// -------------------------------------------------------------------

void BasicUnitReconfigurer::localResetConfiguration()
{
	helper->resetConfiguration();
	for (int i=0; i<getReconfigurationOrder(); i++)
		if (unit[i]!=NULL)
			unit[i]->resetConfiguration();
}

// -------------------------------------------------------------------

void BasicUnitReconfigurer::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool BasicUnitReconfigurer::isConfigured()
{
	if (!AocsObject::isConfigured())
		return false;

	if (!helper->isConfigured())
		return false;

	for (int i=0; i<getReconfigurationOrder(); i++)
		if (unit[i]==NULL)
			return false;

	for (i=0; i<getReconfigurationOrder(); i++)
		if (!unit[i]->isConfigured())
			return false;

	return true;
}

// -------------------------------------------------------------------

void BasicUnitReconfigurer::localReset()
{
	helper->reset();
	for (int i=0; i<getReconfigurationOrder(); i++)
		if (unit[i]!=NULL)
			unit[i]->reset();
}

// -------------------------------------------------------------------

void BasicUnitReconfigurer::reset()
{
	AocsObject::reset();
	localReset();
}

// -------------------------------------------------------------------
// This implementation assumes that units that are configured in have 
// to be switched on and initialized whereas units that are configured
// out are switched off

void BasicUnitReconfigurer::setConfiguration(ConfigurationId n)
{
	if (n != getConfiguration())
	{	unit[getConfiguration()]->switchOff();
		helper->setConfiguration(n);
		unit[getConfiguration()]->switchOn();
		unit[getConfiguration()]->initialize();		
	}
}

// -------------------------------------------------------------------
// This implementation generates a failure event if the reconfiguration
// is not possible because there are no more free configurations 
// This implementation assumes that units that are configured in have 
// to be switched on and initialized whereas units that are configured
// out are switched off

void BasicUnitReconfigurer::reconfigure()
{
	if (canReconfigure())
	{	unit[getConfiguration()]->switchOff();
		helper->reconfigure();
		unit[getConfiguration()]->switchOn();
		unit[getConfiguration()]->initialize();
	}
	else
		reportFailure(this,
						NO_MORE_CONFIGURATION,
						  this,
						    helper->getReconfigurationErrorRecoveryAction());
}

// -------------------------------------------------------------------

void BasicUnitReconfigurer::setUnit(AocsUnit* u, int n)
{
	if ( (n<0) || (n>=getReconfigurationOrder()) )
		reportConfigurationError(this,ILLEGAL_CONFIGURATION,this);

	unit[n]=u;
}

// -------------------------------------------------------------------

AocsUnit* BasicUnitReconfigurer::getUnit(int n)
{
	if ( (n<0) || (n>=getReconfigurationOrder()) )
		reportConfigurationError(this,ILLEGAL_CONFIGURATION,this);

	return unit[n];
}

// -------------------------------------------------------------------

int BasicUnitReconfigurer::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}

// -------------------------------------------------------------------

void BasicUnitReconfigurer::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsObject::writeToTelemetry(tmStream);		// write super object's state

	// TBD : not implemented in framework prototype
}
