// BiasScalingCompensator.cpp
//
// Version	1.0
// Date		18.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/ClassId.h"
#include "../SequentialDataProcessing/BiasScalingCompensator.h"

// -------------------------------------------------------------------
// Define static variables
int BiasScalingCompensator::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------

BiasScalingCompensator::BiasScalingCompensator(Real b, Real s)				
{
	setClassId(ID_BIASSCALECOMPENSATOR);					

	allocateMemory(1,1,0);				// 1 input, 1 output, 0 states

	tmImageLength[shortTm]  = 0;		// Not implemented in fw prototype	
	tmImageLength[normalTm] = 0;	
	tmImageLength[longTm]   = 0;
	tmImageLength[debugTm]  = 0;

	bias = b;
	scalingFactor = s;
}

// -------------------------------------------------------------------

void BiasScalingCompensator::propagationAlgorithm(AocsTime t)
{
	output[0] = bias+scalingFactor*input[0];
}

// -------------------------------------------------------------------

void BiasScalingCompensator::localResetConfiguration()
{
	bias = 0.0;
	scalingFactor = 1.0;
}

// -------------------------------------------------------------------

void BiasScalingCompensator::resetConfiguration()
{
	ControlChannelBlock::resetConfiguration();	// reset super object's state
	localResetConfiguration();
}

// -------------------------------------------------------------------

void BiasScalingCompensator::writeToTelemetry(TelemetryStream* stream)
{
	ControlChannelBlock::writeToTelemetry(stream);		// write super object's state
	
	// Not implemented in fw prototype
}

// -------------------------------------------------------------------

int BiasScalingCompensator::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]+
				ControlChannelBlock::getTelemetryImageLength());
}


