// BiasScalingCompensator.h
//
// Version	1.0
// Date		31.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Control block to implement a compensation of a unit output. Both
// bias and scaling factor compensation are implemented.
//
// The block implements the following single-input-single-output transfer
// function: y = bias+scalingFactor*u
//
// -------------------------------------------------------------------

#ifndef BiasScalingCompensatorH
#define BiasScalingCompensatorH

// -------------------------------------------------------------------

#include "../SequentialDataProcessing/ControlChannelBlock.h"
#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------

class BiasScalingCompensator : public ControlChannelBlock {

	static int tmImageLength[NTMFORMATS];

	Real bias;
	Real scalingFactor;

	virtual void propagationAlgorithm(AocsTime t);
	
	void localResetConfiguration();

public :

	BiasScalingCompensator(Real bias, Real scalingFactor);

	void setScalingFactor(Real newScalingFactor)
		{ scalingFactor = newScalingFactor; }

	void setBias(Real newBias)
		{ bias = newBias; }

	virtual void resetConfiguration();

	virtual int getTelemetryImageLength();
	virtual void writeToTelemetry(TelemetryStream* stream);
};

#endif
