// ControlChannelSuperBlock.h
//
// Version	1.0
// Date		18.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Class for super block components
//
// -------------------------------------------------------------------

#ifndef ControlChannelSuperBlockH
#define ControlChannelSuperBlockH

// -------------------------------------------------------------------

#include "../SequentialDataProcessing/AbstractControlChannel.h"
#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../AocsData/DataItemRead.h"

// -------------------------------------------------------------------

class ControlChannelSuperBlock : public AbstractControlChannel {

	struct IoLink						// Holds connections between 
	{	AbstractControlChannel* cc;		// internal blocks and
		int n;							// external I/O 
	};

	// Array holding connections between internal blocks and external inputs						
	IoLink* inputLink;	

	// Array holding connections between internal blocks and external outputs						
	IoLink* outputLink;	

	void localResetConfiguration();

public :

	ControlChannelSuperBlock(int nInputs, int nOutputs);

	virtual void propagate(AocsTime t);

	// link DataItemRead d to j-th input
	virtual void linkInput(DataItemRead d, int j);

	// link j-th input to i-th output of control channel c
	virtual void linkInput(AbstractControlChannel* c, int i, int j);

	// link i-th input of c to j-th input of super-block
	void linkInputInternal(AbstractControlChannel* c, int i, int j);

	// link i-th output of c to j-th output of super-block
	void linkOutputInternal(AbstractControlChannel* c, int i, int j);

	virtual DataItemRead getOutput(int j);

	virtual void release();

	virtual void hold();

	// pure virtual methods from Resettable
	virtual void reset();

	// pure virtual methods from Configurable
	virtual void resetConfiguration();
	virtual bool isConfigured();
	
};

// -------------------------------------------------------------------
#endif
