// D_Block.cpp
//
// Version	1.0
// Date		18.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../SequentialDataProcessing/D_Block.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"

// -------------------------------------------------------------------
// Define static variables
int D_Block::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------
// Default constructor.

D_Block::D_Block()				
{
	setClassId(ID_D_BLOCK);					

	allocateMemory(1,1,1);				// 1 input, 1 output, 1 state

	tmImageLength[shortTm]  = 0;	
	tmImageLength[normalTm] = 2*getStateOrder()*sizeof(Real);	
	tmImageLength[longTm]   = tmImageLength[normalTm]+sizeof(AocsTime);
	tmImageLength[debugTm]  = tmImageLength[longTm]+getInputOrder()*sizeof(Real)+
									getOutputOrder()*sizeof(Real);

	localResetConfiguration();					
}

// -------------------------------------------------------------------
// Implemented transfer function: y(k+1) = gain*(u(k+1)-u(k))/DT with
// a saturator on the output
// NB This method is only called if t is larger than lastPropagatedTime

void D_Block::propagationAlgorithm(AocsTime t)
{
	output[0] = gain*(input[0]-state[0])/(t-lastPropagatedTime);
	state[0] = input[0];
	
	if (output[0]>maximumDerivative) 
		output[0]=maximumDerivative;

	if (output[0]<-maximumDerivative)
		output[0]=-maximumDerivative;
}

// -------------------------------------------------------------------

void D_Block::localResetConfiguration()
{
	gain = 0.0;
	maximumDerivative = 0.0;
}

// -------------------------------------------------------------------

void D_Block::resetConfiguration()
{
	ControlChannelBlock::resetConfiguration();	// reset super object
	localResetConfiguration();
}

// -------------------------------------------------------------------

void D_Block::writeToTelemetry(TelemetryStream* stream)
{
	ControlChannelBlock::writeToTelemetry(stream);		// write super object's state

	switch(getTelemetryFormat()) 
	{
		case shortTm:
			break;
		case normalTm:
			// write gain 
			break;
		case longTm:
			// write gain and state arrays  
			break;
		case debugTm:
			// write gain and input, output and state arrays 
			break;
	}
}

// -------------------------------------------------------------------

int D_Block::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]+
				ControlChannelBlock::getTelemetryImageLength());
}


