// LimitBlock.cpp
//
// Version	1.0
// Date	13.10.00
// Author	T. Brown
//
// Change History:
//
// -------------------------------------------------------------------

// Include framework header files
#include "../SequentialDataProcessing/LimitBlock.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"

int LimitBlock::tmImageLength[NTMFORMATS] = {0, 0, 0, 0};

// -------------------------------------------------------------------
// Default constructor.
LimitBlock::LimitBlock()
{
	setClassId(ID_ADDERBLOCK);		// assign class identifier

	allocateMemory(1,1,0);				// 1 input, 1 output, 0 states

	localResetConfiguration();
}

// -------------------------------------------------------------------

void LimitBlock::propagationAlgorithm(AocsTime t)
{
	if (input[0] > highLimit)
	{
		output[0] = highLimit;
	}
	else if (input[0] < lowLimit)
	{
		output[0] = lowLimit;
	}
	else
	{
		output[0] = input[0];
	}
}

// -------------------------------------------------------------------

void LimitBlock::localResetConfiguration()
{
	highLimit = 1.0;
	lowLimit = 0.0;
	return;
}

// -------------------------------------------------------------------

void LimitBlock::setLimits(Real high, Real low)
{
	highLimit = high;
	lowLimit = low;
}

// -------------------------------------------------------------------

void LimitBlock::resetConfiguration()
{
	ControlChannelBlock::resetConfiguration();	// reset super object's state
	localResetConfiguration();
}

// -------------------------------------------------------------------

void LimitBlock::writeToTelemetry(TelemetryStream* stream)
{
	// write super object's state
	ControlChannelBlock::writeToTelemetry(stream);

	// TBD - not done in prototype
}

// -------------------------------------------------------------------

int LimitBlock::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]+
			ControlChannelBlock::getTelemetryImageLength());
}


