// RawBusDataConverterIn.h
//
// Version	1.0
// Date		30.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Control block to perform the conversion of bus data from raw to 
// engineering format (conversion of incoming data) for a unit with 
// m input channels.
//
// The following format is assumed for the raw bus data from each channel:
//	- bits 0-14 : binary representation of absolute value of datum
//	- bit 15 :	  sign bit (datum is positive if bit is equal to 1)
//
// The number of channels m and the resolution level for the raw bus 
// datum are passed as constructor parameters.
//
// The channel inputs are of type 'Real' but the bus data are of 'unsigned 
// short' type. The block assumes that the bus data to be converted are 
// overlaid on the TBW bytes of the block input.
//
// -------------------------------------------------------------------

#ifndef RawBusDataConverterInH
#define RawBusDataConverterInH

// -------------------------------------------------------------------

#include "../SequentialDataProcessing/ControlChannelBlock.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------

class RawBusDataConverterIn : public ControlChannelBlock {

	Real resolutionLevel;
	int numberOfChannels;

	virtual void propagationAlgorithm(AocsTime t);
	
public :

	RawBusDataConverterIn(int numberOfChannels, Real resolutionLevel);
};

#endif
