// RawBusDataConverterOut.h
//
// Version	1.0
// Date		30.05.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Control block to perform the conversion of data to be sent to 
// external units from engineering format to raw bus data format 
// (conversion of outgoing data). The unit is assumed to have
// 'numberOfChannels' channels.
//
// The following format is assumed for the raw bus data:
//	- bits 0-14 : binary representation of absolute value of datum
//	- bit 15 :	  sign bit (datum is positive if bit is equal to 1)
//
// The resolution level for the raw bus datum and the number of channels
// are passed as a parameters to the block constructor.
//
// The block output is of type 'Real' but the bus datum is of 'unsigned 
// short' type. The block assumes that the converted bus datum is 
// overlaid on the TBW bytes of the block output.
//
// -------------------------------------------------------------------

#ifndef RawBusDataConverterOutH
#define RawBusDataConverterOutH

// -------------------------------------------------------------------

#include "../SequentialDataProcessing/ControlChannelBlock.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------

class RawBusDataConverterOut : public ControlChannelBlock {

	Real resolutionLevel;
	int numberOfChannels;

	virtual void propagationAlgorithm(AocsTime t);
	
public :

	RawBusDataConverterOut(int numberOfChannels, Real resolutionLevel);

};

#endif
