// TestCaseControlChannel_4.cpp
//
// Version	1.0
// Date		27.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseControlChannel_4.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/Scalar.h"
#include "../../SequentialDataProcessing/I_Block.h"
#include "../../SequentialDataProcessing/P_Block.h"
#include "../../SequentialDataProcessing/TwoByTwoMatrixBlock.h"

// -------------------------------------------------------------------
TestCaseControlChannel_4::TestCaseControlChannel_4():
	TestCaseGenericSetUp(ID_ABSTRACTCONTROLCHANNELBLOCK*10+4,
									"TestControlChannel_4") {
		return;
}

// -------------------------------------------------------------------

void TestCaseControlChannel_4::runTestCase() {

	P_Block block1;
	I_Block block2; 
	TwoByTwoMatrixBlock block3;
	Scalar scalar;

	// Reset the blocks
	block1.reset();
	block2.reset();
	block3.reset();
	
	// Define input signal intensity
	Real s=5;

	// Retrieve data item write serving as source for control block
	DataItemWrite inputSource=scalar.getDataItemWrite(0);
	
	// Configure control block connections
	block1.linkInput(scalar.getDataItemRead(0),0);
	block2.linkInput(&block1,0,0);
	block3.linkInput(&block2,0,0);
	block3.linkInput(&block2,0,1);

	// Set the gain for the proportional block
	Real k=2;
	block1.setGain(k);

	// Define integrator gains
	Real gain=3;
	block2.setGain(gain);

	// Set initial integrator values 
	block2.setState(0,0);
	block2.setState(1,s*k);

	// Set the gains of the 2x2 matrix block
	Real a00=1;
	Real a01=2;
	Real a10=3;
	Real a11=4;
	block3.setMatrixElement(0,0,a00);
	block3.setMatrixElement(0,1,a01);
	block3.setMatrixElement(1,0,a10);
	block3.setMatrixElement(1,1,a11);

	// Set the control block input 
	inputSource.set(s);

	// Integrate over n time intervals
	int n=10;
	AocsTime timeStep=2;
	AocsTime t0=aocsClock.getTime();
	AocsTime t=t0;
	for (int i=0; i<n; i++)
	{	t+=timeStep;
		block3.propagate(t);
		Real dummy1=block1.getOutput(0).get();		// facilitates debugging
		Real dummy2=block2.getOutput(0).get();		// facilitates debugging
		Real dummy30=block3.getOutput(0).get();	// facilitates debugging
		Real dummy31=block3.getOutput(1).get();	// facilitates debugging
	}
	
	// Check correct value of block output
	if ( block3.getOutput(0).get() != s*(gain*timeStep*n)*k*(a00+a01) )
	{	setTestResult(TEST_FAILURE, "Block output is wrong");
		return;
	}

	if ( block3.getOutput(1).get() != s*(gain*timeStep*n)*k*(a10+a11) )
	{	setTestResult(TEST_FAILURE, "Block output is wrong");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
