// TestCaseControlChannel_5.cpp
//
// Version	1.0
// Date		27.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseControlChannel_5.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/DataItemWrite.h"
#include "../../SequentialDataProcessing/I_Block.h"
#include "../../SequentialDataProcessing/D_Block.h"

// -------------------------------------------------------------------
TestCaseControlChannel_5::TestCaseControlChannel_5():
	TestCaseGenericSetUp(ID_ABSTRACTCONTROLCHANNELBLOCK*10+5,
									"TestControlChannel_5") {
		return;
}

// -------------------------------------------------------------------

void TestCaseControlChannel_5::runTestCase() {

	I_Block block1; 
	D_Block block2; 
	Scalar scalar;

	// Reset the block
	block1.reset();
	block2.reset();
	
	// Define input signal intensity
	Real s=5;

	// Define integrator gain
	Real gain1=3;
	block1.setGain(gain1);

	// Define derivative block gain
	Real gain2=9;
	block2.setGain(gain2);

	// Define saturation limit on derivative block
	Real maximumDerivative=1000;
	block2.setMaximumDerivative(maximumDerivative);

	// Retrieve data item write serving as source for control block
	DataItemWrite inputSource=scalar.getDataItemWrite(0);
	
	// Configure control blocks
	block1.linkInput(scalar.getDataItemRead(0),0);
	block2.linkInput(&block1,0,0);

	// Set initial integrator value
	Real initialValue=100;
	block1.setState(0,initialValue);
	block1.setState(1,s);

	// Set the control block input 
	inputSource.set(s);

	// Perform Propagation over n time intervals
	int n=10;
	AocsTime timeStep=4;
	AocsTime t0=aocsClock.getTime();
	AocsTime t=t0;
	for (int i=0; i<n; i++)
	{	t+=timeStep;
		block2.propagate(t);
		Real output1=block1.getOutput(0).get();	// facilitates debugging
		Real output2=block2.getOutput(0).get();	// facilitates debugging
		if ( (block2.getOutput(0).get() != (s*gain2*gain1)) && (i>1) )
		{	setTestResult(TEST_FAILURE, "Block output is wrong");
			return;
		}
	}
	
	// Set the saturation threshold for the derivative block to a very low value
	maximumDerivative=1;
	block2.setMaximumDerivative(maximumDerivative);

	// Perform Propagation over n time intervals with the low saturation value
	for (i=0; i<n; i++)
	{	t+=timeStep;
		block2.propagate(t);
		Real output1=block1.getOutput(0).get();	// facilitates debugging
		Real output2=block2.getOutput(0).get();	// facilitates debugging
		if ( (block2.getOutput(0).get() != maximumDerivative) && (i>1) )
		{	setTestResult(TEST_FAILURE, "Block output is wrong");
			return;
		}
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
