// TestCaseControlChannel_6.cpp
//
// Version	1.0
// Date		27.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseControlChannel_6.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/TwoEulerAngles.h"
#include "../../SequentialDataProcessing/I_Block.h"
#include "../../SequentialDataProcessing/TwoByTwoMatrixBlock.h"
#include "../../SequentialDataProcessing/ControlChannelSuperBlock.h"

// -------------------------------------------------------------------
TestCaseControlChannel_6::TestCaseControlChannel_6():
	TestCaseGenericSetUp(ID_ABSTRACTCONTROLCHANNELBLOCK*10+6,
									"TestControlChannel_6") {
		return;
}

// -------------------------------------------------------------------

void TestCaseControlChannel_6::runTestCase() {

	// Create two integral blocks and one 2x2 matrix block
	I_Block b1, b2;
	TwoByTwoMatrixBlock matrixBlock;

	// Set the gains of the I blocks
	Real b1Gain=2.0;
	Real b2Gain=4.0;
	b1.setGain(b1Gain);
	b2.setGain(b2Gain);

	// The 2x2 matrix simply exchanges the two inputs with the two outputs
	matrixBlock.setMatrixElement(0,0,0);
	matrixBlock.setMatrixElement(0,1,1);
	matrixBlock.setMatrixElement(1,0,1);
	matrixBlock.setMatrixElement(0,0,0);

	// Connect the I blocks to the inputs of the 2x2 matrix block
	matrixBlock.linkInput(&b1,0,0);
	matrixBlock.linkInput(&b2,0,1);

	// Create the super block
	ControlChannelSuperBlock superBlock(2,2);

	// Embed and link the blocks in the superblock
	superBlock.linkInputInternal(&b1,0,0);
	superBlock.linkInputInternal(&b2,0,1);
	superBlock.linkOutputInternal(&matrixBlock,0,0);
	superBlock.linkOutputInternal(&matrixBlock,1,1);
	b1.setEnclosingControlChannel(&superBlock);
	b2.setEnclosingControlChannel(&superBlock);
	matrixBlock.setEnclosingControlChannel(&superBlock);

	// Create a dummy data to serve as input for the super block
	TwoEulerAngles inputSource;

	// Set a value for the input source
	Real input1 = 5;
	Real input2= 10;
	inputSource.getDataItemWrite(0).set(input1);
	inputSource.getDataItemWrite(1).set(input1);

	// Link the external inputs of the super block
	superBlock.linkInput(inputSource.getDataItemRead(0),0);
	superBlock.linkInput(inputSource.getDataItemRead(1),1);

	// Check that the superblock is correctly configured
	if ( !superBlock.isConfigured() )
	{	setTestResult(TEST_FAILURE, "Superblock is incorrectly configured");
		return;
	}

	// Advance the clock and propagate the superblock to the new time
	aocsClock.run(0);
	superBlock.propagate( aocsClock.getTime() );

	// Reset the superblock
	superBlock.reset();

	// Check that the super block outputs are again zero
	if (superBlock.getOutput(0).get()!=0)
	{	setTestResult(TEST_FAILURE, "Block output is wrong");
		return;
	}
	if (superBlock.getOutput(1).get()!=0)
	{	setTestResult(TEST_FAILURE, "Block output is wrong");
		return;
	}

	// Check that no failure or configuration events have been created
	if ( failureEvtRep.getCounter() != failureEvtN )
	{	setTestResult(TEST_FAILURE, "Failure event was generated");
		return;
	}
	if ( configEvtRep.getCounter() != configEvtN )
	{	setTestResult(TEST_FAILURE, "Configuration event was generated");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
