// SplitterBlock.h
//
// Version	1.0
// Date		17.11.00
// Author	A. Pasetti
//
// Change History:
//
// -------------------------------------------------------------------
// Control block to implement a signal splitter. The block has 1
// input an n outputs. Its transfer function is: 
//
//		y[j]=u[0]	for j=0..n-1
//
// Splitters are useful when more than one control block must be 
// connected to the same internal input in an enclosing super block.
//
// -------------------------------------------------------------------

#ifndef SplitterBlockH
#define SplitterBlockH

// -------------------------------------------------------------------

#include "../SequentialDataProcessing/ControlChannelBlock.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------

class SplitterBlock : public ControlChannelBlock {

	static ClassId classId;
	static int tmImageLength[NTMFORMATS];

	virtual void propagationAlgorithm(AocsTime t);

public :

	SplitterBlock(int numberOfOutputs);

	virtual int getTelemetryImageLength();
	virtual void writeToTelemetry(TelemetryStream* stream);
};

#endif 
