// XmathUcbBlock.h
//
// Version	1.0
// Date		29.02.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Control block acting as a container for a UCB-style autocode procedure
// generated by Xmath.
//
// NB: This block assumes that the basic type 'Real' is defined as 'double'
// -------------------------------------------------------------------

#ifndef XmathUcbBlockH
#define XmathUcbBlockH

// -------------------------------------------------------------------

#include "../SequentialDataProcessing/ControlChannelBlock.h"
#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/Constants.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------

class XmathUcbBlock : public ControlChannelBlock {

	static int tmImageLength[NTMFORMATS];

	int iinfo[4];		// required for UCB interface
	Real rinfo[4];		// see section 14.2.11 of System Build UM
	int* I_P;
	Real* R_P;
	Real* stateDer;		// equivalent to XD in UCB interface

	int n,m,p;			// input, output and state size
	int nR_P, nI_P;		// size of integer and real parameter arrays

	UcbHookFunction ucbHook;		// pointer to UCB hook subroutine (from autocode)

	// Recovery action invoked when UCB routine reports an error
	RecoveryAction* recoveryAction;

	// Default sampling time as defined by the constructor
	AocsTime samplingTime;

	virtual void propagationAlgorithm(AocsTime t);

	void localReset();
	void localResetConfiguration();

	XmathUcbBlock()		// default constructor cannot be used
		{};

public :

	XmathUcbBlock(int n, int m, int p, int nR_P, int nI_P, 
		AocsTime samplingTime, UcbHookFunction ucbHook);

	virtual void reset();
	virtual void resetConfiguration();

	virtual int getTelemetryImageLength();
	virtual void writeToTelemetry(TelemetryStream* stream);

	// Straightforward setter and getter methods
	void setUcbErrorRecoveryAction(RecoveryAction* r)
		{ recoveryAction = r; }

	RecoveryAction* getUcbErrorRecoveryAction()
		{ return recoveryAction; }

	void setSamplingTime(AocsTime sT)
		{ rinfo[1]=(Real)sT; }
};

#endif
