// XmathUcbPidBlock.cpp
//
// Version	1.0
// Date		17.03.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

// Include framework header files
#include "../Xmath/Include.h"
#include "../SequentialDataProcessing/XmathUcbPidBlock.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------
// Define static variables
int XmathUcbPidBlock::tmImageLength[NTMFORMATS];

// -------------------------------------------------------------------
// Default constructor.

XmathUcbPidBlock::XmathUcbPidBlock(AocsTime samplingTime):
	XmathUcbBlock(1,1,2,0,0,samplingTime,&pid_ucbhook)				

{
	setClassId(ID_XMATHUCBPIDBLOCK);		

	tmImageLength[shortTm]  = 0;	
	tmImageLength[normalTm] = 3*sizeof(Real);	
	tmImageLength[longTm]   = tmImageLength[normalTm];
	tmImageLength[debugTm]  = tmImageLength[longTm];
}

// -------------------------------------------------------------------
void XmathUcbPidBlock::setKp(Real newKp)
	{ kp = newKp; }

// -------------------------------------------------------------------
Real XmathUcbPidBlock::getKp()
	{ return kp; }
	
// -------------------------------------------------------------------
void XmathUcbPidBlock::setKi(Real newKi)
	{ ki = newKi; }

// -------------------------------------------------------------------
Real XmathUcbPidBlock::getKi()
	{ return ki; }

// -------------------------------------------------------------------
void XmathUcbPidBlock::setKd(Real newKd)
	{ kd = newKd; }

// -------------------------------------------------------------------
Real XmathUcbPidBlock::getKd()
	{ return kd; }

// -------------------------------------------------------------------

void XmathUcbPidBlock::writeToTelemetry(TelemetryStream* stream)
{
	ControlChannelBlock::writeToTelemetry(stream);		// write super object's state

	switch(getTelemetryFormat()) 
	{
		case shortTm:
			break;
		case normalTm:
			// write the three PID gains 
			break;
		case longTm:
			// TBW
			break;
		case debugTm:
			// TBW
			break;
	}
}

// -------------------------------------------------------------------

int XmathUcbPidBlock::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]+
				XmathUcbBlock::getTelemetryImageLength());
}


