// TestCaseSystemManagement_1.cpp
//
// Version	1.0
// Date		23.01.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseSystemManagement_1.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../BasicObjects/AocsObject.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../SystemManagement/SystemManager.h"
#include "../../TelemetryManagement/CyclingTelemetryModeManager.h"
#include "../../AocsEvent/ModeEventRepository.h"
#include "../../ModeManagement/ModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"
#include "../../AocsEvent/ChangeEventRepository.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../AocsEvent/SystemEvent.h"

// -------------------------------------------------------------------
TestCaseSystemManagement_1::TestCaseSystemManagement_1():
	TestCaseGenericSetUp(ID_SYSTEMMANAGER*10+2,"TestCaseSystemManagement_1") {
		return;
}

// -------------------------------------------------------------------

void TestCaseSystemManagement_1::runTestCase() {

	// Create a few test objects
	AocsObject dummy1;
	AocsObject dummy2;
	AocsObject dummy3;

	// Get the system manager
	SystemManager* sm=AocsObject::getSystemManager();

	// Check that the system is configured
	if (!sm->isSystemConfigured())
	{	setTestResult(TEST_FAILURE, "System should be configured");
		return;
	}

	// Check that there are no events in the system repository
	if (sm->getSystemEventRepository()->getCounter()!=0)
	{	setTestResult(TEST_FAILURE, "System event repository should be empty");
		return;
	}

	// Create and configure object list
	ObjectListTemplate<AocsObject> list;
	list.allocateMemory(10);

	// Create an (unconfigured) mode manager
	CyclingTelemetryModeManager mm(1,0,0);

	// Check that the system is not configured (due to the unconfigured
	// mode manager)
	if (sm->isSystemConfigured())
	{	setTestResult(TEST_FAILURE, "System should not be configured");
		return;
	}

	// Configure the mode manager
	ModeEventRepository modeEvtRep;
	modeEvtRep.setRepositorySize(4);
	ChangeEventRepository changeEvtRep;
	changeEvtRep.setRepositorySize(4);
	ModeManager::setChangeEventRepository(&changeEvtRep);
	ModeManager::setModeEventRepository(&modeEvtRep);
	RootObject dummy;
	NullModeChangeAction mca;
	mm.loadImplementer(0,0,&dummy);
	mm.setModeChangeAction(&mca);

	// Check that the system is now configured
	if (!sm->isSystemConfigured())
	{	setTestResult(TEST_FAILURE, "System should be configured");
		return;
	}

	// Retrieve the number of configuration events
	int configEvtN=AocsObject::getConfigurationEventRepository()->getCounter();

	// Force the creation of a configuration event
	list.allocateMemory(10);		// illegal operation!

	// Check that a configuration event was created
	if (AocsObject::getConfigurationEventRepository()->getCounter()!=configEvtN+1)
	{	setTestResult(TEST_FAILURE, "Configuration event should have been created");
		return;
	}

	// Perform a system reset
	sm->systemReset();

	// Check that a SYSTEM_RESET event was created in the system repository
	if (sm->getSystemEventRepository()->getCounter()!=1)
	{	setTestResult(TEST_FAILURE, "System reset event should have been created");
		return;
	}
	if (sm->getSystemEventRepository()->latestSystemEvent()->getEventType()!=SYSTEM_RESET)
	{	setTestResult(TEST_FAILURE, "System reset event should have been created");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
