// AttitudeSlewTelecommand.cpp
//
// Version	1.0
// Date		25.11.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../TelecommandManagement/AttitudeSlewTelecommand.h"
#include "../ManoeuvreManagement/AttitudeSlew.h"
#include "../ManoeuvreManagement/ManoeuvreManager.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventTypeId.h"
#include "../AocsData/DataItemWrite.h"

// -------------------------------------------------------------------
// Define static variables
ManoeuvreManager* AttitudeSlewTelecommand::manoeuvreManager=NULL;

// -------------------------------------------------------------------

AttitudeSlewTelecommand::AttitudeSlewTelecommand(
	 AocsTime timeTag, AttitudeSlew* m, float error, float att_e, 
	 AocsTime ts, AocsTime te, Real* item, AocsTime* timeTagItem)
												:Telecommand(timeTag)
{
	setClassId(ID_MANOEUVRETELECOMMAND);			

	manoeuvre = m;
	errorThreshold = error;
	att_end = att_e;
	t0 = ts;
	tf = te;
	itemToSet = item;
	timeTagItemToSet = timeTagItem;
}

// -------------------------------------------------------------------
// The attitude slew manoeuvre is configured and then loaded into the 
// manoeuvre manager. There is no check that the load operation was 
// successful: the method always returns a "TC successful" code.

EventType AttitudeSlewTelecommand::execute()
{
	manoeuvre->configure(t0,tf,att_end,
							DataItemWrite(timeTagItemToSet,itemToSet),
								errorThreshold);
	
	manoeuvreManager->addManoeuvre(manoeuvre);

	return TC_SUCCESS;
}
