// ModeChangeTransactionTelecommand.cpp
//
// Version	1.0
// Date		05.08.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../TelecommandManagement/ModeChangeTransactionTelecommand.h"
#include "../TelecommandManagement/TransactionTelecommand.h"
#include "../TelecommandManagement/TelecommandManager.h"
#include "../ModeManagement/ModeManager.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------

ModeChangeTransactionTelecommand::ModeChangeTransactionTelecommand(
	 AocsTime timeTag, ModeManager* m, int n):TransactionTelecommand(timeTag)
{
	setClassId(ID_MODECHANGETRANSACTIONTELECOMMAND);			

	modeManager = m;
	newMode = (unsigned char)n;
}

// -------------------------------------------------------------------

EventType ModeChangeTransactionTelecommand::execute()
{
	// Recover current mode and put in on the stack
	TransactionTelecommand::getTelecommandManager()->pushInt(
		modeManager->getMode());

	// Perform mode change
	modeManager->setMode(newMode);

	// Check whether mode change was successful
	if (modeManager->getMode() == (int)newMode)
		return TransactionTelecommand::execute();
	else
	{	// restore stack and unExecute previous TC in TC transaction
		TransactionTelecommand::getTelecommandManager()->popInt();	
		return TransactionTelecommand::unExecute();
	}
}

// -------------------------------------------------------------------

EventType ModeChangeTransactionTelecommand::unExecute()
{
	// Recover old mode from the stack
	int oldMode=TransactionTelecommand::getTelecommandManager()->popInt();

	// Restore old mode
	modeManager->setMode(oldMode);

	// Check whether restore operation was successful
	if (modeManager->getMode() == (int)oldMode)
		return TransactionTelecommand::unExecute();
	else
		return TC_TRANS_UNDO_FAILURE;
}
