// TestCaseTelecommand_1.cpp
//
// Version	1.0
// Date		06.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseTelecommand_1.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsEvent/TelecommandEvent.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../FailureRecovery/NullRecoveryAction.h"
#include "../../TelecommandManagement/Telecommand.h"
#include "../../TelecommandManagement/TelecommandManager.h"
#include "../../TelecommandManagement/TestTelecommandLoader.h"

// -------------------------------------------------------------------
TestCaseTelecommand_1::TestCaseTelecommand_1():
	TestCaseGenericSetUp(ID_TELECOMMANDMANAGER*10+1,
									"TestCaseTelecommand_1") {
		return;
}

// -------------------------------------------------------------------

void TestCaseTelecommand_1::runTestCase() {

	// Create the TC manager and check that it is not configured
	int ntc=3;

	TelecommandManager tcm(ntc);

	if (tcm.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Configure the TC manager
	NullRecoveryAction nra;
	tcm.setTelecommandListFullRecoveryAction(&nra);
	tcm.setTelecommandStackErrorRecoveryAction(&nra);

	TestTelecommandLoader ttl;
	tcm.setTelecommandLoader(&ttl);

	if (!tcm.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Create four dummy telecommands with different time tags
	Telecommand tc1(aocsClock.getTime());
	Telecommand tc2(aocsClock.getTime()+aocsClock.getClockPeriod());
	Telecommand tc3(aocsClock.getTime()+aocsClock.getClockPeriod());
	Telecommand tc4(aocsClock.getTime()+2*aocsClock.getClockPeriod());

	// Disable the second telecommand
	tc2.disable();

	// Code to explore layout of objects in memory
	char* memchar;
	int* memint;
	memchar = (char*)&tc2;
	memint = (int*)&tc2;

	// Load the first three telecommands
	tcm.loadTelecommand(&tc3);
	tcm.loadTelecommand(&tc2);
	tcm.loadTelecommand(&tc1);

	// Check that the telecommand count is correct
	if (tcm.getNumberOfTelecommands()!=3)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Check that three tc events were created
	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+3)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_LOADED)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Attempt to load the fourth telecommand. This should produce a 
	// failure event in the TC manager due to the TC list being 
	// already full
	tcm.loadTelecommand(&tc4);

	if (tcm.getNumberOfTelecommands()!=3)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	if (AocsObject::getFailureEventRepository()->getCounter()!=failureEvtN+1)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}
	if (AocsObject::getFailureEventRepository()->latestFailureEvent()->
			getEventType()!=TC_LIST_FULL)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Run the TC manager. Only TC1 should be executed (it is due for
	// execution and it is enabled)
	tcm.run(0);

	if (tcm.getNumberOfTelecommands()!=2)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	if (ttl.getReleaseCounter()!=1)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+4)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_SUCCESS)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Advance time by two cycles
	aocsClock.run(0);
	aocsClock.run(0);

	// Run the TC manager. Both TC2 and TC3 are due for execution but only
	// TC3 should be executed as TC2 is disabled
	tcm.run(0);

	if (tcm.getNumberOfTelecommands()!=0)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	if (ttl.getReleaseCounter()!=3)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+6)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// Before exiting, check failure and configuration error event numbers
	if (AocsObject::getFailureEventRepository()->getCounter()!=failureEvtN+1)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}
	if (AocsObject::getConfigurationEventRepository()->getCounter()!=configEvtN)
	{	setTestResult(TEST_FAILURE, "Telecommand test 1 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
