// TestCaseTelecommand_2.cpp
//
// Version	1.0
// Date		06.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseTelecommand_2.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsEvent/TelecommandEvent.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../FailureRecovery/NullRecoveryAction.h"
#include "../../TelecommandManagement/ReconfigureTelecommand.h"
#include "../../TelecommandManagement/ModeChangeTelecommand.h"
#include "../../TelecommandManagement/TelemetryFormatTelecommand.h"
#include "../../TelecommandManagement/TelecommandManager.h"
#include "../../TelecommandManagement/TestTelecommandLoader.h"
#include "../../ModeManagement/AocsMissionModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"
#include "../../ReconfigurationManagement/BasicUnitReconfigurer.h"
#include "../../AocsUnit/MacsTcController.h"
#include "../../AocsUnit/GyrPrototype.h"

// -------------------------------------------------------------------
TestCaseTelecommand_2::TestCaseTelecommand_2():
	TestCaseGenericSetUp(ID_TELECOMMANDMANAGER*10+2,
									"TestCaseTelecommand_2") {
		return;
}

// -------------------------------------------------------------------
// Test telecommands to: change mode, perform reconfiguration, change
// telemetry format

void TestCaseTelecommand_2::runTestCase() {

	// Create and configure the TC manager 
	TelecommandManager tcm(3);

	NullRecoveryAction nra;
	tcm.setTelecommandListFullRecoveryAction(&nra);
	tcm.setTelecommandStackErrorRecoveryAction(&nra);

	TestTelecommandLoader ttl;
	tcm.setTelecommandLoader(&ttl);

	if (!tcm.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	// Create and configure a mode manager and a configuration manager 
	// to act as dummy objects upon which telecommands can operate
	int defaultConfig=0;

	AocsMissionModeManager mm(3,0,0);
	NullModeChangeAction mca;
	mm.setModeChangeAction(&mca);

	BasicUnitReconfigurer bur(2,0,defaultConfig);
	short dummy_1,dummy_2,dummy_3;
	MacsTcController macsTcController(&dummy_1,&dummy_2,&dummy_3);
	macsTcController.setMaxPolling(2);
	GyrPrototype gyr_1(0,0), gyr_2(0,0);
	gyr_1.setAocsUnitHardware(&macsTcController);
	gyr_2.setAocsUnitHardware(&macsTcController);
	bur.setUnit(&gyr_1,0);
	bur.setUnit(&gyr_2,1);

	// Create test telecommands 
	int targetMode=1;
	TelemetryFormat targetTmFormat=longTm;
	ModeChangeTelecommand mcTC(0,&mm,targetMode);
	ReconfigureTelecommand rTC(0,&bur);
	TelemetryFormatTelecommand tfTC(0,&mm,targetTmFormat);

	// Load telecommands in the TC manager
	tcm.loadTelecommand(&mcTC);
	tcm.loadTelecommand(&rTC);
	tcm.loadTelecommand(&tfTC);

	// Run the TC manager and check execution of TC's
	tcm.run(0);

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+6)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_SUCCESS)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	if (mm.getMode()!=targetMode)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	if (bur.getConfiguration()==defaultConfig)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	if (mm.getTelemetryFormat()!=targetTmFormat)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	if (tcm.getNumberOfTelecommands()!=0)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	// Reload and reexecute the reconfigure TC. It should now fail since 
	// there are no more free configurations
	tcm.loadTelecommand(&rTC);

	tcm.run(0);

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+8)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_FAILURE)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	// Before exiting, check failure and configuration error event numbers
	// NB Two failure events are created as a result of the GYR reconfiguration
	// which causes MACS instructions to be sent to the GYR units. The MACS
	// instructions fail and failure events are created
	if (AocsObject::getFailureEventRepository()->getCounter()!=failureEvtN+2)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}
	if (AocsObject::getConfigurationEventRepository()->getCounter()!=configEvtN)
	{	setTestResult(TEST_FAILURE, "Telecommand test 2 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
