// TestCaseTelecommand_3.cpp
//
// Version	1.0
// Date		06.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseTelecommand_3.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsEvent/TelecommandEvent.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../FailureRecovery/NullRecoveryAction.h"
#include "../../TelecommandManagement/ReconfigureTelecommand.h"
#include "../../TelecommandManagement/ModeChangeTelecommand.h"
#include "../../TelecommandManagement/TelemetryFormatTelecommand.h"
#include "../../TelecommandManagement/ReconfigureTransactionTelecommand.h"
#include "../../TelecommandManagement/ModeChangeTransactionTelecommand.h"
#include "../../TelecommandManagement/TelemetryFormatTransactionTelecommand.h"
#include "../../TelecommandManagement/TelecommandManager.h"
#include "../../TelecommandManagement/TestTelecommandLoader.h"
#include "../../ModeManagement/AocsMissionModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"
#include "../../ReconfigurationManagement/BasicUnitReconfigurer.h"
#include "../../AocsUnit/MacsTcController.h"
#include "../../AocsUnit/GyrPrototype.h"

// -------------------------------------------------------------------
TestCaseTelecommand_3::TestCaseTelecommand_3():
	TestCaseGenericSetUp(ID_TELECOMMANDMANAGER*10+3,
									"TestCaseTelecommand_3") {
		return;
}

// -------------------------------------------------------------------

void TestCaseTelecommand_3::runTestCase() {

	// Create and configure the TC manager 
	TelecommandManager tcm(3);

	NullRecoveryAction nra;
	tcm.setTelecommandListFullRecoveryAction(&nra);
	tcm.setTelecommandStackErrorRecoveryAction(&nra);

	TestTelecommandLoader ttl;
	tcm.setTelecommandLoader(&ttl);

	if (!tcm.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	// Create and configure a mode manager and a configuration manager 
	// to act as dummy objects upon which telecommands can operate
	int defaultConfig=0;
	int defaultMode=1;

	AocsMissionModeManager mm(3,defaultMode,0);
	NullModeChangeAction mca;
	mm.setModeChangeAction(&mca);

	BasicUnitReconfigurer bur(2,0,defaultConfig);
	short dummy_1,dummy_2,dummy_3;
	MacsTcController macsTcController(&dummy_1,&dummy_2,&dummy_3);
	macsTcController.setMaxPolling(2);
	GyrPrototype gyr_1(0,0), gyr_2(0,0);
	gyr_1.setAocsUnitHardware(&macsTcController);
	gyr_2.setAocsUnitHardware(&macsTcController);
	bur.setUnit(&gyr_1,0);
	bur.setUnit(&gyr_2,1);

	// Create test transaction telecommands 
	int targetMode=2;
	TelemetryFormat targetTmFormat=longTm;

	ModeChangeTransactionTelecommand mcTC(0,&mm,targetMode);
	ReconfigureTransactionTelecommand rTC(0,&bur);
	TelemetryFormatTransactionTelecommand tfTC(0,&mm,targetTmFormat);

	// Configure static part of transaction telecommands
	TransactionTelecommand::setTelecommandManager(&tcm);

	// Link the transaction telecommands
	mcTC.setNextTransactionTelecommand(&tfTC);
	tfTC.setNextTransactionTelecommand(&rTC);

	// Load the transaction telecommand in the TC manager
	tcm.loadTelecommand(&mcTC);

	// Run the TC manager and check execution of TC's
	tcm.run(0);

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+2)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_TRANS_SUCCESS)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	if (mm.getMode()!=targetMode)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	if (bur.getConfiguration()==defaultConfig)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	if (mm.getTelemetryFormat()!=targetTmFormat)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	if (tcm.getNumberOfTelecommands()!=0)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	// Disable one of the transaction telecommands, reload the transaction
	// TC and check that it will not be executed
	tfTC.disable();
	
	tcm.loadTelecommand(&mcTC);
	tcm.run(0);

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+4)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_UNLOADED)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	// Reset the mode manager to its original state and renable telemetry TC
	mm.reset();

	tfTC.enable();

	// Reload and reexecute the transaction TC. It should now fail since 
	// the reconfigre TC fails (there are no more free configurations)
	tcm.loadTelecommand(&mcTC);

	tcm.run(0);

	if (tcm.getTelecommandEventRepository()->getCounter()!=tcEvtN+6)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}
	if (tcm.getTelecommandEventRepository()->latestTelecommandEvent()->
			getEventType()!=TC_TRANS_FAILURE)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	// Check that the mode change and telemetry change telecommands did
	// not take effect
	if (mm.getMode()!=defaultMode)	
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	if (mm.getTelemetryFormat()!=targetTmFormat)	
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	// Before exiting, check failure and configuration error event numbers
	// NB Two failure events are created as a result of the GYR reconfiguration
	// which causes MACS instructions to be sent to the GYR units. The MACS
	// instructions fail and failure events are created
	if (AocsObject::getFailureEventRepository()->getCounter()!=failureEvtN+2)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}
	if (AocsObject::getConfigurationEventRepository()->getCounter()!=configEvtN)
	{	setTestResult(TEST_FAILURE, "Telecommand test 3 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}
