// TelecommandManager.h
//
// Version	1.0
// Date		05.08.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// Telecommand manager class
// -------------------------------------------------------------------

#ifndef TelecommandManagerH
#define TelecommandManagerH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"
#include "../GeneralInclude/Constants.h"
#include "../BasicObjects/AocsObject.h"
#include "../OperatingSystemObjects/Runnable.h"
#include "../ObjectList/ObjectListTemplate.h"

// -------------------------------------------------------------------

class TelecommandManager : public AocsObject, public Runnable {

	static int tmImageLength[NTMFORMATS];
	static TelecommandEventRepository* tcEventRepository;

	// List of pending telecommands
	ObjectListTemplate<Telecommand> tcList;

	// Telecommand loader
	TelecommandLoader* tcLoader;

	// Stacks for telecommand data and their pointers
	int intStack[TC_INT_STACK_SIZE];
	Real realStack[TC_REAL_STACK_SIZE];
	int intStackPointer;
	int realStackPointer;

	// Recovery action for attempts (by the TC loader) to load a
	// TC when the list of pending TC is already full
	RecoveryAction* tcListFullRecoveryAction;

	// Recovery action for overflow or underflow of internal stacks 
	// used by telecommands
	RecoveryAction* tcStackErrorRecoveryAction;

	// Local reset methods
	void localResetConfiguration();
	void localReset();

public:

	TelecommandManager(int maxNumberPendingTc);

	// Method to load a telecommand
	void loadTelecommand(Telecommand* telecommand);

	// Scheduler entry point
	virtual void run(AocsTime deadline);

	// Telecommand stack management operations
	void pushInt(int v);
	int popInt();
	void pushReal(Real v);
	Real popReal();
	void resetIntStack();
	void resetRealStack();

	// Return number of pending telecommands
	int getNumberOfTelecommands();

	// Virtual methods inherited from Resettable
	virtual void reset();		

	// Virtual methods inherited from Configurable
	virtual void resetConfiguration();		
	virtual bool isConfigured();	
	
	// Reset static configuration
	static void resetStaticConfiguration();
	
	// Virtual methods inherited from interface Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual int getTelemetryImageLength();

	// Straightforward getter and setter methods
	static void setTelecommandEventRepository(TelecommandEventRepository* r)
		{ tcEventRepository = r; }
	static TelecommandEventRepository* getTelecommandEventRepository()
		{ return tcEventRepository; }
	
	void setTelecommandLoader(TelecommandLoader* l)
		{ tcLoader = l; }
	TelecommandLoader* getTelecommandLoader()
		{ return tcLoader; }

	void setTelecommandListFullRecoveryAction(RecoveryAction* r)
		{ tcListFullRecoveryAction = r; }
	RecoveryAction* getTelecommandListFullRecoveryAction()
		{ return tcListFullRecoveryAction; }

	void setTelecommandStackErrorRecoveryAction(RecoveryAction* r)
		{ tcStackErrorRecoveryAction = r; }
	RecoveryAction* getTelecommandStackErrorRecoveryAction()
		{ return tcStackErrorRecoveryAction; }
};

// -------------------------------------------------------------------
#endif