// TelemetryFormatTransactionTelecommand.cpp
//
// Version	1.0
// Date		07.08.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../TelecommandManagement/TelemetryFormatTransactionTelecommand.h"
#include "../TelecommandManagement/TransactionTelecommand.h"
#include "../TelecommandManagement/TelecommandManager.h"
#include "../TelemetryManagement/Telemeterable.h"
#include "../GeneralInclude/ClassId.h"
#include "../AocsEvent/EventTypeId.h"

// -------------------------------------------------------------------

TelemetryFormatTransactionTelecommand::TelemetryFormatTransactionTelecommand(
	 AocsTime timeTag, Telemeterable* t, TelemetryFormat n):
		TransactionTelecommand(timeTag)
{
	setClassId(ID_TELEMETRYFORMATTRANSACTIONTELECOMMAND);			

	telemeterable = t;
	newFormat = n;
}

// -------------------------------------------------------------------

EventType TelemetryFormatTransactionTelecommand::execute()
{
	// Recover current format and put in on the stack
	TransactionTelecommand::getTelecommandManager()->pushInt(
		telemeterable->getTelemetryFormat());

	// Change the telemetry format
	telemeterable->setTelemetryFormat(newFormat);

	// Check whether telemetry format change was successful
	if (telemeterable->getTelemetryFormat() == newFormat)
		return TransactionTelecommand::execute();
	else
	{	// restore stack and unExecute previous TC in TC transaction
		TransactionTelecommand::getTelecommandManager()->popInt();	
		return TransactionTelecommand::unExecute();
	}
}

// -------------------------------------------------------------------

EventType TelemetryFormatTransactionTelecommand::unExecute()
{
	// Recover current format from the stack
	TelemetryFormat oldFormat;

	switch (TransactionTelecommand::getTelecommandManager()->popInt())
	{
		case 0:
			oldFormat = shortTm;
			break;
		case 1:
			oldFormat = normalTm;
			break;
		case 2:
			oldFormat = longTm;
			break;
		case 3:
			oldFormat = debugTm;
			break;
	}

	// Restore the old telemetry format
	telemeterable->setTelemetryFormat(oldFormat);

	// Check whether the restore operation was successful
	if (telemeterable->getTelemetryFormat() == oldFormat)
		return TransactionTelecommand::unExecute();
	else
		return TC_TRANS_UNDO_FAILURE;
}
