// TransactionTelecommand.h
//
// Version	1.0
// Date		05.08.00
// Author	A. Pasetti

#ifndef TransactionTelecommandH
#define TransactionTelecommandH

// -------------------------------------------------------------------
// Base class for telecommand transaction. A telecommand transaction
// is a sequence of linked telecommands that can be executed as a 
// single entity and that, if one telecommand in the sequence fails,
// offer the possibility of unexecution thus restoring the original
// state of the system.
// -------------------------------------------------------------------

#include "../TelecommandManagement/Telecommand.h"
#include "../GeneralInclude/ForwardDeclarations.h"
#include "../GeneralInclude/BasicTypes.h"

// -------------------------------------------------------------------

class TransactionTelecommand : public Telecommand {

	TransactionTelecommand* next;
	TransactionTelecommand* previous;

	static TelecommandManager* tcManager;

public :

	TransactionTelecommand(AocsTime t);

	virtual EventType execute();

	virtual EventType unExecute();

	virtual bool canExecute();

	bool isEnabled();

	// Getter and setter methods for linking transaction Tc's
	TransactionTelecommand* getNextTransactionTelecommand()
		{ return next; }
	void setNextTransactionTelecommand(TransactionTelecommand* t);

	TransactionTelecommand* getPreviousTransactionTelecommand()
		{ return previous; }
	void setPreviousTransactionTelecommand(TransactionTelecommand* t);

	// Getter and setter methods for TC manager
	static TelecommandManager* getTelecommandManager()
		{ return tcManager; }
	static void setTelecommandManager(TelecommandManager* m)
		{ tcManager = m; }

};

// -------------------------------------------------------------------
#endif