// DmaTelemetryStream.h
//
// Version	1.0
// Date		07.04.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// DMA telemetry stream : the telemetry data are written to a DMA buffer
// -------------------------------------------------------------------

#ifndef DmaTelemetryStreamH
#define DmaTelemetryStreamH

// -------------------------------------------------------------------

#include "../GeneralInclude/ForwardDeclarations.h"
#include "../TelemetryManagement/TelemetryStream.h"
#include "../BasicObjects/AocsObject.h"

// -------------------------------------------------------------------

class DmaTelemetryStream : public AocsObject, public TelemetryStream {

	static int tmImageLength[NTMFORMATS];

	// Telemetry frame counter
	int tmFrameCounter;

	// Start address of the DMA buffer
	char* dmaBuffer;

	// Size of DMA buffer (in bytes)
	int bufferSize;

	// Offset where the next byte is to be written
	int nextByte;

	// Offset where the next bit is to be written (not used in f/w prototype)
	int nextBit;

	// Reset the local configuration state
	void localResetConfiguration();

protected :

	// Methods to write header information to the TM buffer
	virtual void writeFrameNumber(int n);		// write the frame number 
	virtual void writeNumberOfBytes(int n);		// write the number of TM bytes
	virtual void writeNumberOfBits(int n);		// write the number of TM bits

public:

	DmaTelemetryStream();

	// Methods to write TM data to the DMA buffer
	virtual void write(float d);				// write the float d to TM
	virtual void write(double d);				// write the double d to TM
	virtual void write(int d);					// write the integer d to TM
	virtual void write(unsigned int d);			// write the unsigned integer d to TM
	virtual void write(short d);				// write the short d to TM
	virtual void write(unsigned short d);		// write the unsigned short d to TM
	virtual void write(unsigned char d);		// write the unsigned char d to TM
	virtual void write(bool d);					// write the boolean flag (1 bit only) to TM
	virtual void write(char* d, int n);			// write n bytes to TM starting from d

	// Not implemented in the test TM stream
	virtual void write(int d, int n, int m)		// write bits n to m of integer d to TM
		{ return; }
	virtual void write(short d, int n, int m)	// write bits n to m of short d to TM
		{ return; }
	virtual void write(char d, int n, int m)	// write bits n to m of char d to TM
		{ return; }

	// Buffer Management operations
	virtual void flushBuffer();					// flush TM buffer
	virtual void resetBuffer();					// reset TM buffer

	// Virtual methods inherited from interface Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual int getTelemetryImageLength();

	// Virtual methods inherited from interface Configurable
	virtual void resetConfiguration();		
	virtual bool isConfigured();		

	// Straightforward getter and setter methods
	void setDmaBufferStartAddress(char* s)
		{ dmaBuffer = s; }
	char* getDmaBufferStartAddress()
		{ return dmaBuffer; }

	virtual int getBufferSize()					// return TM buffer size (in bytes)
		{ return bufferSize; }
	virtual void setBufferSize(int size)		// set TM buffer size (in bytes)
		{ bufferSize=size; }

};

// -------------------------------------------------------------------
#endif