// TestCaseTelemetry_1.cpp
//
// Version	1.0
// Date		03.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseTelemetry_1.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/TwoEulerAngles.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../AocsEvent/ConfigurationEvent.h"
#include "../../AocsEvent/SystemEvent.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../AocsEvent/FailureEventRepository.h"
#include "../../AocsEvent/ConfigurationEventRepository.h"
#include "../../BasicObjects/AocsObject.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../ModeManagement/AocsMissionModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"

// -------------------------------------------------------------------
TestCaseTelemetry_1::TestCaseTelemetry_1():
	TestCaseGenericSetUp(ID_TELEMETRYMANAGER*10+1,
									"TestCaseTelemetry_1") {
		return;
}

// -------------------------------------------------------------------

void TestCaseTelemetry_1::runTestCase() {

	// Create dummy objects to be used as test TM objects
	AocsObject ao;
	TwoEulerAngles euler;
	Scalar s;
	AocsEvent evt;
	ConfigurationEvent ce;
	FailureEvent fevt;
	FailureEventRepository fer;
	ConfigurationEventRepository cer;

	// Check TM image length in normal TM mode
	if (ao.getTelemetryImageLength()/8 != 3)			
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (euler.getTelemetryImageLength()/8 != 8+3)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (s.getTelemetryImageLength()/8 != 4+3)			
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (evt.getTelemetryImageLength()/8 != 4)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (ce.getTelemetryImageLength()/8 != 4)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (fevt.getTelemetryImageLength()/8 != 4)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (fer.getTelemetryImageLength()/8 != 6)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	if (cer.getTelemetryImageLength()/8 != 6)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}

	// Check TM image length in long TM mode
	ao.setTelemetryFormat(longTm);
	if (ao.getTelemetryImageLength()/8 != 3)			
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	euler.setTelemetryFormat(longTm);
	if (euler.getTelemetryImageLength()/8 != 8+8+3)	
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	s.setTelemetryFormat(longTm);
	if (s.getTelemetryImageLength()/8 != 4+4+3)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	evt.setTelemetryFormat(longTm);
	if (evt.getTelemetryImageLength()/8 != 6+4)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	ce.setTelemetryFormat(longTm);
	if (ce.getTelemetryImageLength()/8 != 2+6+4)	
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	fevt.setTelemetryFormat(longTm);
	if (fevt.getTelemetryImageLength()/8 != 4+6+4)	
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	fer.setTelemetryFormat(longTm);
	if (fer.getTelemetryImageLength()/8 != 2+6)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}
	cer.setTelemetryFormat(longTm);
	if (cer.getTelemetryImageLength()/8 != 2+6)		
	{	setTestResult(TEST_FAILURE, "Telemetry test 1 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}



