// TestCaseTelemetry_3.cpp
//
// Version	1.0
// Date		03.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "TestCaseTelemetry_3.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/TwoEulerAngles.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../AocsEvent/SystemEvent.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../BasicObjects/AocsObject.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../ModeManagement/AocsMissionModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"
#include "../../TelemetryManagement/MemorySection.h"
#include "../../TelemetryManagement/TelemetryManager.h"
#include "../../TelemetryManagement/CyclingTelemetryModeManager.h"
#include "../../TelemetryManagement/DmaTelemetryStream.h"

// -------------------------------------------------------------------
TestCaseTelemetry_3::TestCaseTelemetry_3():
	TestCaseGenericSetUp(ID_TELEMETRYMANAGER*10+3,
									"TestCaseTelemetry_3") {
		return;
}

// -------------------------------------------------------------------

void TestCaseTelemetry_3::runTestCase() {

	// Create and load two arrays of short integers
	char array1[20], array2[20];
	for (int i=0; i<20; i++)
	{	array1[i]=i;
		array2[i]=10*i;
	}

	// Create a memory section object
	MemorySection ms;

	// Check that the memory section is not configured
	if (ms.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telemetry test 3 failed");
		return;
	}

	// Configure the memory section
	ms.defineMemorySection((char*)&array1[0],(char*)&array1[10]);

	// Check that the memory section is configured
	if (!ms.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telemetry test 3 failed");
		return;
	}
	
	// Create a telemetry list and load it with the memory section
	ObjectListTemplate<Telemeterable> tmList;
	tmList.allocateMemory(10);
	tmList.addObject(&ms);

	// Create and configure a telemetry mode manager with a single mode
	CyclingTelemetryModeManager tmModeManager(1,0,0);
	tmModeManager.loadTelemetryList(0,&tmList);
	NullModeChangeAction nra;
	tmModeManager.setModeChangeAction(&nra);

	// Create a DMA TM stream
	DmaTelemetryStream tmStream;

	// Allocate a memory area for the telemetry stream buffer
	char dmaBuffer[100];

	// Configure the DMA telemetry stream
	tmStream.setBufferSize(50);
	tmStream.setDmaBufferStartAddress(dmaBuffer);

	// Create and configure a telemetry manager
	TelemetryManager tmManager;
	tmManager.setTelemetryStream(&tmStream);
	tmManager.setTelemetryModeManager(&tmModeManager);
	
	// Run the telemetry manager 
	tmManager.run(0);

	// Overlay the DMA buffer with an array of char 
	char* shortDmaBuffer;
	shortDmaBuffer = (&dmaBuffer[8]);

	// Check that the memory section has been copied to the DMA buffer (recall
	// that the first five bytes of the DMA buffer contain header information
	// and the bytes 6 to 8 contain the AocsObject TM image)
	for (i=0; i<10; i++)
		if (shortDmaBuffer[i]!=array1[i])
		{	setTestResult(TEST_FAILURE, "Telemetry test 3 failed");
			return;
		}

	// Change the configuration of the memory section
	ms.defineMemorySection((char*)&array2[0],(char*)&array2[5]);

	// Run the telemetry manager 
	tmManager.run(0);

	// Check that the memory section has been copied to the DMA buffer
	for (i=0; i<5; i++)
		if (shortDmaBuffer[i]!=array2[i])
	{	setTestResult(TEST_FAILURE, "Telemetry test 3 failed");
		return;
	}

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}

