// TestCaseTelemetry_3.cpp
//
// Version	1.0
// Date		03.02.01
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include <stdio.h>  

#include "TestCaseTelemetry_3.h"
#include "../../GeneralInclude/ClassId.h"
#include "../../GeneralInclude/Constants.h"
#include "../../GeneralInclude/CompilerSwitches.h"
#include "../../AocsData/Scalar.h"
#include "../../AocsData/TwoEulerAngles.h"
#include "../../AocsEvent/FailureEvent.h"
#include "../../AocsEvent/SystemEvent.h"
#include "../../AocsEvent/EventTypeId.h"
#include "../../BasicObjects/AocsObject.h"
#include "../../ObjectList/ObjectListTemplate.h"
#include "../../ModeManagement/AocsMissionModeManager.h"
#include "../../ModeManagement/NullModeChangeAction.h"
#include "../../TelemetryManagement/DmaTelemetryStream.h"
#include "../../TelemetryManagement/TelemetryManager.h"
#include "../../TelemetryManagement/CyclingTelemetryModeManager.h"

// -------------------------------------------------------------------
TestCaseTelemetry_3::TestCaseTelemetry_3():
	TestCaseGenericSetUp(ID_TELEMETRYMANAGER*10+3,
									"TestCaseTelemetry_3") {
		return;
}

// -------------------------------------------------------------------

void TestCaseTelemetry_3::runTestCase() {

	// Create dummy objects to be used as test TM objects
	AocsObject ao1, ao2, ao3;
	TwoEulerAngles euler1, euler2, euler3;

	// Initialize the Euler angle values
	euler1.getDataItemWrite(0).set(1);
	euler2.getDataItemWrite(0).set(2);
	euler3.getDataItemWrite(0).set(3);

	// Create a telemetry list and load it
	ObjectListTemplate<Telemeterable> tmList;
	tmList.allocateMemory(10);
	tmList.addObject(&ao1);
	tmList.addObject(&ao2);
	tmList.addObject(&ao3);
	tmList.addObject(&euler1);
	tmList.addObject(&euler2);
	tmList.addObject(&euler3);
	tmList.addObject(AocsObject::getConfigurationEventRepository());

	// Create and configure a telemetry mode manager with a single mode
	CyclingTelemetryModeManager tmModeManager(1,0,0);
	tmModeManager.loadTelemetryList(0,&tmList);
	NullModeChangeAction nra;
	tmModeManager.setModeChangeAction(&nra);

	// Force the creation of configuration events
	tmList.allocateMemory(20);					// illegal --> configuration event
	tmModeManager.loadTelemetryList(1,&tmList);	// illegal --> configuration event

	// Create a DMA TM stream
	DmaTelemetryStream tmStream;

	// Check that the TM stream is not configured
	if (tmStream.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telemetry test 3 failed");
		return;
	}

	// Allocate a memory area for the telemetry stream buffer
	char dmaBuffer[100];

	// Configure the DMA telemetry stream
	tmStream.setBufferSize(50);
	tmStream.setDmaBufferStartAddress(dmaBuffer);

	// Check that the TM stream is configured
	if (!tmStream.isConfigured())
	{	setTestResult(TEST_FAILURE, "Telemetry test 3 failed");
		return;
	}

	// Create and configure a telemetry manager
	TelemetryManager tmManager;
	tmManager.setTelemetryStream(&tmStream);
	tmManager.setTelemetryModeManager(&tmModeManager);
	
	// Run the telemetry manager 
	tmManager.run(0);

	// Write the content of the dmaBuffer to the output file
#ifdef MS_HOST
	fprintf(out,"DMA Buffer Content: \n");
	for (int i=0; i<25; i++)
	{	unsigned char temp = dmaBuffer[i];
		fprintf(out,"%2x ",temp);
	}
	fprintf(out,"\n");
	for (i=25; i<50; i++)
	{	unsigned char temp = dmaBuffer[i];
		fprintf(out,"%2x ",temp);
	}
	fprintf(out,"\n");
#else
	printf("DMA Buffer Content: \n");
	for (int i=0; i<25; i++)
	{	unsigned char temp = dmaBuffer[i];
		printf("%2x ",temp);
	}
	printf("\n");
	for (i=25; i<50; i++)
	{	unsigned char temp = dmaBuffer[i];
		printf("%2x ",temp);
	}
	printf("\n");
#endif

	// If this point is reached, test was successful
	setTestResult(TEST_SUCCESS,NULL);
	return;
}

