// TelemetryManager.cpp
//
// Version	1.0
// Date		07.04.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------

#include "../TelemetryManagement/TelemetryManager.h"
#include "../TelemetryManagement/TelemetryModeManager.h"
#include "../GeneralInclude/ClassId.h"
#include "../GeneralInclude/Constants.h"
#include "../AocsEvent/EventTypeId.h"
#include "../TelemetryManagement/TelemetryStream.h"

// -------------------------------------------------------------------
// Define static variables
int TelemetryManager::tmImageLength[NTMFORMATS];		

// -------------------------------------------------------------------

TelemetryManager::TelemetryManager()
{
	setClassId(ID_TELEMETRYMANAGER);		// assign class identifier

	tmImageLength[shortTm]  = 0;			// not implemented in f/w prototype
	tmImageLength[normalTm] = 0;
	tmImageLength[longTm]   = 0;
	tmImageLength[debugTm]  = 0;

	localResetConfiguration();
}

// -------------------------------------------------------------------

void TelemetryManager::localResetConfiguration()
{
	tmStream = NULL;
	modeManager = NULL;
	tooManyTmData = NULL;
}

// -------------------------------------------------------------------

void TelemetryManager::resetConfiguration()
{
	AocsObject::resetConfiguration();
	localResetConfiguration();
}

// -------------------------------------------------------------------

bool TelemetryManager::isConfigured()
{
	if (!AocsObject::isConfigured())
		return false;

	if (tmStream==NULL)
		return false;

	if (modeManager==NULL)
		return false;
	
	return true;
}

// -------------------------------------------------------------------

void TelemetryManager::run(AocsTime deadline)
{
	// Load the telemetry list to be sent to the TM stream in this frame
	tmList = modeManager->getTelemetryList();

	// Initialize the counter of bytes sent to the TM stream
	int tmDataSize=0;

	// Reset the telemetry buffer
	tmStream->resetBuffer();

	// Get telemetry buffer size
	int tmStreamSize=8*tmStream->getBufferSize();

	// Send the TM list to the TM stream 
	Telemeterable* t;
	for (t=tmList->first(); !tmList->isLast(); t=tmList->next())
	{	
		tmDataSize+=t->getTelemetryImageLength();
		if (tmDataSize>tmStreamSize)
		{	reportFailure(this,TOO_MANY_TM_DATA,this,tooManyTmData);
			break;
		}
		t->writeToTelemetry(tmStream);
	}

	// Flush the TM buffer 
	tmStream->flushBuffer();
}

// -------------------------------------------------------------------
// From Telemeterable interface

int TelemetryManager::getTelemetryImageLength()
{
	return (tmImageLength[getTelemetryFormat()]
								+AocsObject::getTelemetryImageLength());
}

// -------------------------------------------------------------------
// From Telemeterable interface

void TelemetryManager::writeToTelemetry(TelemetryStream* tmStream)
{
	AocsObject::writeToTelemetry(tmStream);		// write super object's state

	// TBD : not implemented in framework prototype
}
