// TelemetryStream.h
//
// Version	1.0
// Date		17.01.00
// Author	A. Pasetti
//
// -------------------------------------------------------------------
// This is an interface class
// -------------------------------------------------------------------

#ifndef TelemetryStreamH
#define TelemetryStreamH

// -------------------------------------------------------------------

class TelemetryStream {

protected :

	virtual void writeFrameNumber(int n)=0;			// write the frame number 
	virtual void writeNumberOfBytes(int n)=0;		// write the number of TM bytes
	virtual void writeNumberOfBits(int n)=0;			// write the number of TM bits

public:

	virtual void write(char* d, int n)=0;			// write n bytes to TM starting from d
	virtual void write(double d)=0;					// write the float d to TM
	virtual void write(float d)=0;					// write the float d to TM
	virtual void write(int d)=0;					// write the integer d to TM
	virtual void write(unsigned int d)=0;			// write the unsigned integer d to TM
	virtual void write(short d)=0;					// write the short d to TM
	virtual void write(unsigned short d)=0;			// write the unsigned short d to TM
	virtual void write(unsigned char d)=0;			// write the unsigned char d to TM
	virtual void write(bool d)=0;					// write the boolean flag (1 bit only) to TM
	virtual void write(int d, int n, int m)=0;		// write bits n to m of integer d to TM
	virtual void write(short d, int n, int m)=0;	// write bits n to m of short d to TM
	virtual void write(char d, int n, int m)=0;		// write bits n to m of char d to TM
	virtual void flushBuffer()=0;					// flush TM buffer
	virtual void resetBuffer()=0;					// reset TM buffer
	virtual int getBufferSize()=0;					// return TM buffer size (in bytes)
	virtual void setBufferSize(int size)=0;			// set the TM buffer size (in bytes)
};

// -------------------------------------------------------------------
#endif