// TestTelemetryStream.h
//
// Version	1.1
// Date		07.04.00
// Author	A. Pasetti
//
// Change Record:
//	1.1: added include files
//
// -------------------------------------------------------------------
// Test telemetry stream : the telemetry data are written to a file 
//						   (Visual Studio host) or to the output devide
//						   (ERC32 host)
// -------------------------------------------------------------------

#ifndef TestTelemetryStreamH
#define TestTelemetryStreamH

#include <stdio.h>		// required for file operations

#include "../BasicObjects/AocsObject.h"
#include "../TelemetryManagement/TelemetryStream.h"

// -------------------------------------------------------------------

class TestTelemetryStream : public AocsObject, public TelemetryStream {

	static int tmImageLength[NTMFORMATS];
	static ClassId classId;

	// Output file where TM data are written
	FILE* tmStreamFile;

	// Size of telemetry buffer (in bytes)
	int bufferSize;

	// Frame counter
	int tmFrameCounter;

	// Byte counter (number of bytes sent to TM stream)
	int byteCounter;

	// Bit counter (number of bits sent to TM stream)
	int bitCounter;

protected :

	// Methods to write header information to the TM buffer
	virtual void writeFrameNumber(int n);		// write the frame number 
	virtual void writeNumberOfBytes(int n);		// write the number of TM bytes
	virtual void writeNumberOfBits(int n)		// write the number of TM bits
		{ return; }

public:

	// The constructor opens the output file
	TestTelemetryStream();

	// The destructor closes the output file
	~TestTelemetryStream();

	virtual void write(float d);				// write the float d to TM
	virtual void write(double d);				// write the double d to TM
	virtual void write(int d);					// write the integer d to TM
	virtual void write(unsigned int d);			// write the unsigned integer d to TM
	virtual void write(short d);				// write the short d to TM
	virtual void write(unsigned short d);		// write the unsigned short d to TM
	virtual void write(bool d);					// write the boolean flag (1 bit only) to TM

	// Not implemented in the test TM stream
	virtual void write(char* d, int n)			// write n bytes to TM starting from d
		{ return; }
	virtual void write(int d, int n, int m)		// write bits n to m of integer d to TM
		{ return; }
	virtual void write(short d, int n, int m)	// write bits n to m of short d to TM
		{ return; }
	virtual void write(char d, int n, int m)	// write bits n to m of char d to TM
		{ return; }
	virtual void write(unsigned char d)		// write the unsigned char d to TM
		{ return; }

	// Buffer Management operations
	virtual void flushBuffer();					// flush TM buffer
	virtual void resetBuffer();					// reset TM buffer
	virtual int getBufferSize()					// return TM buffer size (in bytes)
		{ return bufferSize; }
	virtual void setBufferSize(int size)		// set TM buffer size (in bytes)
		{ bufferSize=size; }

	// Virtual methods inherited from interface Telemeterable
	virtual void writeToTelemetry(TelemetryStream* stream);
	virtual int getTelemetryImageLength();

};

// -------------------------------------------------------------------
#endif