/*----------------------------------------------------------------------------
--                       AutoCode (TM) 62mx1118
--
--                         Copyright (C) 1999
--                       INTEGRATED SYSTEMS, INC.
--
--  Unpublished work - rights reserved under the U.S. Copyright Act.  Use,
--  duplication, or disclosure by the government is subject to restrictions
--  set forth in the ISI commercial license agreement.
**----------------------------------------------------------------------------
**
**  File       : sa_math.h
**  Project    : Autocode/C
**
**  Abstract:
**
**      Definitions for additional AutoCode math function support.
*/

#ifndef _SA_MATH
#define _SA_MATH

#include "sa_defn.h" 
#include "sa_types.h"

#if AC100_TARGET
extern int        abs( int i );         /* defined in <stdlib.h> */
#endif

#if (FC_)
#define urand  urand_
#define nrand  nrand_
#define ourand ourand_
#endif

#if (_TMS320C30 || _TMS320C40 || ANSI_PROTOTYPES)
extern RT_INTEGER iminv  (int arg1,...);
extern RT_INTEGER imaxv  (int arg1,...);
extern RT_FLOAT   rminv  (int arg1,...);
extern RT_FLOAT   rmaxv  (int arg1,...);
#else
extern RT_INTEGER iminv  ();
extern RT_INTEGER imaxv  ();
extern RT_FLOAT   rminv  ();
extern RT_FLOAT   rmaxv  ();
#endif
EXTERN_FUNC(RT_FLOAT  interf,   (RT_FLOAT arg1, RT_FLOAT arg2) );
EXTERN_FUNC(RT_FLOAT  unionf,   (RT_FLOAT arg1, RT_FLOAT arg2) );
EXTERN_FUNC(RT_FLOAT  trg,      (RT_FLOAT arg0, RT_FLOAT arg1,
                                    RT_FLOAT arg2, RT_FLOAT arg3) );
EXTERN_FUNC(RT_FLOAT  isi_quad, (RT_FLOAT arg0, RT_FLOAT arg1,
                                    RT_FLOAT arg2, RT_FLOAT arg3, 
                                    RT_FLOAT arg4) );
EXTERN_FUNC(void      ourand,   (RT_INTEGER *seed, RT_FLOAT ouLast,
                                    RT_FLOAT timeInterval,
                                    RT_FLOAT timeConst, RT_FLOAT *ou) );
EXTERN_FUNC(void      nrand,    (RT_INTEGER *seed, RT_FLOAT *N1) );
EXTERN_FUNC(void      urand,    (RT_INTEGER *TheSeed, RT_FLOAT *RandNum) );

EXTERN_FUNC(void record_delay_in,  (RT_DURATION tstart, RT_DURATION time,
                                       RT_FLOAT *u, RT_INTEGER nu,
                                       RT_FLOAT *rpar, RT_INTEGER *ipar) );

EXTERN_FUNC(void interp_delay_out, (RT_DURATION tstart, RT_DURATION time,
                                       RT_FLOAT *y, RT_INTEGER ny,
                                       RT_FLOAT *rpar, RT_INTEGER *ipar) );

#if (PGI860)
/*************************************************************
* Redefine the PGI double precision math routines to the PGI *
* single precision routines due to errors in the double ones.*
* This works for both double and single precision models.    *
**************************************************************/
#undef acos
#undef asin
#undef atan
#undef atan2
#undef cos
#undef cosh
#undef exp
#undef fabs
#undef log
#undef log10
#undef pow
#undef sqrt
#undef sin
#undef sinh
#undef tan
#undef tanh

#define acos(a)    acosf(a)
#define asin(a)    asinf(a)
#define atan(a)    atanf(a)
#define atan2(a,b) atan2f(a,b)
#define cos(a)     cosf(a)
#define cosh(a)    coshf(a)
#define exp(a)     expf(a)
#define fabs(a)    fabsf(a)
#define log(a)     logf(a)
#define log10(a)   log10f(a)
#define pow(a,b)   powf(a,b)
#define sqrt(a)    sqrtf(a)
#define sin(a)     sinf(a)
#define sinh(a)    sinhf(a)
#define tan(a)     tanf(a)
#define tanh(a)    tanhf(a)
#endif


/*===================================*/
/*========== Useful Macros ==========*/
/*===================================*/

#define PI_OVER_TWO 1.5707963

/* Re-define the acos function for i387 until Metaware fixes hcc library */
#ifdef I387
#define acos(x) (PI_OVER_TWO - asin((double) (x)))
#endif

#define CVT_FLOAT_BOOLEAN(x)  ((x) <= 0 ? 0 : 1)

#define ABS(x)        ((x) >  0  ? (x) : -(x))
#ifndef MAX
#define MAX(x,y)      ((x) > (y) ? (x) :  (y))
#endif
#ifndef MIN
#define MIN(x,y)      ((y) > (x) ? (x) :  (y))
#endif
#define NINT(x)       ((x) <  0  ? (int)(x - 0.5) : (int)(x + 0.5))
#define TRUNCATE(x)   ((x) <  0  ? ceil(x)     : floor(x))
#define ROUND(x)      ((x) <  0  ? ceil(x-0.5) : floor(x+0.5))
#define ITRUNCATE(x)  ((x) <  0  ? (int)ceil(x)     : (int)floor(x))
#define IROUND(x)     ((x) <  0  ? (int)ceil(x-0.5) : (int)floor(x+0.5))
#define BOUND(x,L,U)  ((x) <  L  ? L : ((x) > U ? U : (x)))
#define SGN(x)        ((x) < 0 ? -1 : ((x) == 0 ? 0 : 1))
#define DECIDE(a)     ((a) > 0 ?  1 : -1)

#define BITAND(x,y)   ((x) & (y))
#define BITOR(x,y)    ((x) | (y))
#define BITNOT(x)     (~x)
#define BTEST(x,y)    (((x) &  (1 << (y))) != 0)
#define BSET(x,y)     ((x)  |  (1 << (y)))
#define BCLEAR(x,y)   ((x)  & ~(1 << (y)))
#define BTOGGLE(x,y)  ((x)  ^  (1 << (y)))
#define BLSHIFT(x,y)  ((x) << (y))
#define BRSHIFT(x,y)  ((x) >> (y))

#define ISWAP(a,b)  \
{ RT_INTEGER _temp; \
  _temp = a; a = b; b = _temp; \
}
 
#define RSWAP(a,b)  \
{ RT_FLOAT _temp; \
  _temp = a; a = b; b = _temp; \
}

#endif

